@@ -1,4 +1,4 @@
-// Copyright (c) 2002-2003 Rob Kaper <cap@capsi.com>
+// Copyright (c) 2002-2004 Rob Kaper <cap@capsi.com>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -25,7 +25,8 @@
 #include <kio/job.h>
 #include <kurl.h>
 
-class KLatencyTimer;
+class KExtendedSocket;
+class QTime;
 
 class Monopigator : public QObject
 {
@@ -37,7 +38,7 @@ public:
 	void loadData(const KURL &);
 
 signals:
-	void monopigatorAdd(QString host, QString port, QString version, int users);
+	void monopigatorAdd(QString ip, QString host, QString port, QString version, int users);
 	void finished();
 	void timeout();
 
@@ -59,15 +60,20 @@ class MonopigatorEntry : public QObject, public QListViewItem
 Q_OBJECT
 
 public:
-	MonopigatorEntry(QListView *parent, QString host, QString latency, QString version, QString users, QString port);
+	MonopigatorEntry(QListView *parent, QString host, QString latency, QString version, QString users, QString port, QString ip);
 	int compare(QListViewItem *i, int col, bool ascending) const;
+	bool isDev() const;
 
 private slots:
-	void updateLatency(int msec);
+	void resolved();
+	void connected();
+	void showDevelopmentServers(bool show);
 
 private:
-	KLatencyTimer *m_latencyTimer;
+	KExtendedSocket *m_latencySocket;
+	QTime time;
 	QListView *m_parent;
+	bool m_isDev;
 };
 
 #endif
