@@ -82,7 +82,7 @@ SelectServer::SelectServer(bool useMonopigatorOnStart, bool hideDevelopmentServe
 	connect(m_refreshButton, SIGNAL(clicked()), this, SLOT(slotRefresh()));
 
 	// Connect
-	m_connectButton = new KPushButton(BarIcon("forward", KIcon::SizeSmall), i18n("Connect"), this);
+	m_connectButton = new KPushButton(BarIconSet("forward", KIcon::SizeSmall), i18n("Connect"), this);
 	m_connectButton->setEnabled(false);
 	buttonBox->addWidget(m_connectButton);
 
@@ -116,7 +116,7 @@ void SelectServer::initMonopigator()
 	emit msgStatus(i18n("Retrieving server list..."));
 
 	m_refreshButton->setGuiItem(KGuiItem(i18n("Reload Server List"), "reload"));
-	m_monopigator->loadData(KURL( "http://monopd.unixcode.org/"));
+	m_monopigator->loadData(KURL( "http://monopd-gator.kde.org/"));
 }
 
 void SelectServer::slotMonopigatorAdd(QString ip, QString host, QString port, QString version, int users)
