@@ -22,11 +22,12 @@
 
 Estate::Estate(int estateId) : QObject()
 {
-	m_estateId = estateId;
+	m_id = estateId;
 	m_name = QString::null;
 	m_owner = 0;
 	m_houses = 0;
 	m_price = 0;
+	m_money = 0;
 	m_estateGroup = 0;
 	m_changed = m_canBeOwned = m_canBuyHouses = m_canSellHouses = m_isMortgaged = m_canToggleMortgage = false;
 	m_bgColor = QColor();
@@ -138,6 +139,20 @@ void Estate::setCanToggleMortgage(const bool canToggleMortgage)
 	}
 }
 
+void Estate::setMoney(int money)
+{
+	if (m_money != money)
+	{
+		m_money = money;
+		m_changed = true;
+	}
+}
+
+int Estate::money()
+{
+	return m_money;
+}
+
 void Estate::update(bool force)
 {
 	if (m_changed || force)
