@@ -19,7 +19,9 @@
 
 #include <qobject.h>
 
-class EstateGroup : public QObject
+#include "libatlantic_export.h"
+
+class LIBATLANTIC_EXPORT EstateGroup : public QObject
 {
 Q_OBJECT
 
