@@ -15,9 +15,9 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-  $Id: kplayerlist.h,v 1.7 2001/10/02 04:37:35 hoefkens Exp $
+  $Id: kplayerlist.h 212185 2003-03-07 22:11:39Z waba $
 
 */
 
