@@ -15,9 +15,9 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-  $Id: kbgng.cpp,v 1.4.4.1 2003/02/13 03:48:24 staikos Exp $
+  $Id: kbgng.cpp 253371 2003-09-23 16:20:40Z aacid $
 
 */
 
@@ -35,7 +35,6 @@
 #include <qbuttongroup.h>
 #include <qcheckbox.h>
 #include <kconfig.h>
-#include <iostream.h>
 #include <klocale.h>
 #include <kmainwindow.h>
 #include <klineeditdlg.h>
@@ -46,7 +45,7 @@
 
 #include <version.h>
 
-#include <iostream.h>
+#include <iostream>
 
 
 /*
@@ -231,13 +230,6 @@ void KBgEngineNg::slotClientDisconnected(Q_UINT32, bool)
     cerr << "KBgEngineNg::slotClientDisconnected" << endl;
 }
 
-void KBgEngineNg::slotPlayerInput(QDataStream &msg, KPlayer *p)
-{
-    Q_INT32 move;
-    msg >>  move;
-    kdDebug(true, PROG_COOKIE) << "  Player " << p->id() << " moved: " << move << endl;
-}
-
 
 
 
@@ -589,7 +581,7 @@ KBgPlayer * KBgEngineNg::createPlayer(int i, QString name)
 {
     KBgPlayer *p = new KBgPlayer();
 
-    if (name != QString::null)
+    if (!name.isNull())
 	p->setName(name);
 
     p->findProperty(KGamePropertyBase::IdName)->setEmittingSignal(true);
@@ -610,8 +602,6 @@ void KBgEngineNg::initGame()
 
     connect(_game, SIGNAL(signalPlayerJoinedGame(KPlayer *)),
 	    this, SLOT(slotPlayerJoinedGame(KPlayer *)));
-    connect(_game, SIGNAL(signalPlayerInput(QDataStream &, KPlayer *)),
-	    this, SLOT(slotPlayerInput(QDataStream &, KPlayer *)));
     connect(_game, SIGNAL(signalCreatePlayer(KPlayer *&, int, int, bool, KGame *)),
 	    this, SLOT(slotCreatePlayer(KPlayer *&, int, int, bool, KGame *)));
 
