@@ -341,7 +341,7 @@ void KBgBoard::readConfig()
  * Get the font the board cells should use for the display of
  * numbers and cube value.
  */
-QFont KBgBoard::getFont()
+QFont KBgBoard::getFont() const
 {
 	return boardFont;
 }
@@ -705,7 +705,7 @@ void KBgBoard::sendMove()
  * This is overloaded from QWidget, since it has to pass the new
  * background color to the child widgets (the cells).
  */
-void KBgBoard::setBackgroundColor(QColor col)
+void KBgBoard::setBackgroundColor(const QColor &col)
 {
 	if (col != backgroundColor()) {
 		QWidget::setBackgroundColor(col);
@@ -727,7 +727,7 @@ void KBgBoard::resizeEvent(QResizeEvent *)
         checkerDiam = (int)((width()/15-2)<(height()/10.0-2) ?
 			    (width()/15-2) : (height()/10.0-2));
 
-	if (checkerDiam < MINIMUM_CHECKER_SIZE)
+	if (checkerDiam < MINIMUM_CHECKER_SIZE) 
 		checkerDiam = MINIMUM_CHECKER_SIZE;
 
 	for (int i = 0; i < 14; ++i) {
@@ -2912,5 +2912,7 @@ QSize KBgBoard::minimumSizeHint() const
 	return QSize(MINIMUM_CHECKER_SIZE * 15, MINIMUM_CHECKER_SIZE * 11);
 }
 
+QSize KBgBoard::sizeHint() const {
+	return QSize(MINIMUM_CHECKER_SIZE *15*4,MINIMUM_CHECKER_SIZE*11*2);
+}
 
-// EOF
