@@ -141,7 +141,7 @@ class KBgBoard : public QWidget
 	 * Sets the background color and passes the info to the
 	 * child widgets
 	 */
-	virtual void setBackgroundColor(QColor col);
+	virtual void setBackgroundColor(const QColor &col);
 
 	/**
 	 * Prints the baord along with some basic info onto the
@@ -174,7 +174,7 @@ class KBgBoard : public QWidget
 	 * Get the font the board cells should use for the display of
 	 * numbers and cube value.
 	 */
-	QFont getFont();
+	QFont getFont() const;
 
 	/**
 	 * This function has to be reimplemented to provide a minimum size for
@@ -291,6 +291,7 @@ public slots:
 	/* ************************************************** */
 
 protected:
+  virtual QSize sizeHint() const;
 
 	QColor baseColors[2];
 	QFont boardFont;
