@@ -2,39 +2,20 @@
 
   Copyright (C) 2001 Jens Hoefkens
   jens@hoefkens.com
-  
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
-  
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-  
-*/
-
-/*
-  $Log: kbgstatus.cpp,v $
-  Revision 1.6.2.1  2002/12/06 12:44:00  lunakl
-  Max size limit for sscanf().
-
-  Revision 1.6  2002/07/23 21:44:51  hoefkens
-  finally a fix for the longstanding bug with not recognizing the correct
-  number of moves.
-
-  Revision 1.5  2001/05/02 04:59:59  hoefkens
-  Minor cleanup. Removed dynamic allocation of board_ array.
-
-  Revision 1.4  2001/05/02 04:41:09  hoefkens
-  Removed the upper limit of 64 for the cube. Unlike FIBS, GNUbg does not
-  limit the max. value of the cube. However, we still enforce the cube to
-  be a power of 2.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
