@@ -28,8 +28,8 @@
 #include "kbg.h"
 #include "version.h"
 
-static const char *description = I18N_NOOP("A Backgammon program for the KDE.");
-static const char *notice      = I18N_NOOP("This is a graphical backgammon program. It supports "
+static const char description[] = I18N_NOOP("A Backgammon program for KDE");
+static const char notice[]      = I18N_NOOP("This is a graphical backgammon program. It supports "
 					   "backgammon games\nwith other players, games against "
 					   "computer engines like GNU bg and even\n"
 					   "on-line games on the 'First Internet Backgammon Server'.");
