@@ -65,14 +65,14 @@ bool KBRandomShotStrategy::hasMoreShots()
 {
 	if(m_parent == 0)
 	{
-		if((!m_destroying) && m_prevShots->count() > 0)
+		if((!m_destroying) && m_prevShots.count() > 0)
 		{
-			QPoint *pos = m_prevShots->last();
-			int state = m_battleField->ownState(pos->x(), pos->y());
+			QPoint pos = m_prevShots.last();
+			int state = m_battleField->ownState(pos.x(), pos.y());
 			if(state == KBattleField::HIT)
 			{
 				m_destroying = true;
-				m_destroyer->destroyShipAt(*pos);
+				m_destroyer->destroyShipAt(pos);
 			}
 		}
 		if(m_destroying)
@@ -98,5 +98,5 @@ bool KBRandomShotStrategy::hasMoreShots()
 
 void KBRandomShotStrategy::shotAt(const QPoint &pos)
 {
-	m_prevShots->append(new QPoint(pos));
+	m_prevShots.append(pos);
 }
