@@ -28,7 +28,6 @@
 #include <kfiledialog.h>
 #include <kscoredialog.h>
 #include <kstatusbar.h>
-#include <kkeydialog.h>
 
 #include "kbounce.h"
 #include "game.h"
@@ -45,8 +44,8 @@ KJezzball::KJezzball()
     m_backgroundDir = config->readPathEntry( "BackgroundDir" );
     m_showBackground = config->readBoolEntry( "ShowBackground", false );
 
-    initXMLUI();
     statusBar();
+    initXMLUI();
 
     m_soundAction -> setChecked((config->readBoolEntry( "PlaySounds", true )));
 
@@ -105,6 +104,7 @@ KJezzball::KJezzball()
 
     setFocusPolicy(QWidget::StrongFocus);
     setFocus();
+    setupGUI();
 }
 
 KJezzball::~KJezzball()
@@ -130,22 +130,16 @@ void KJezzball::initXMLUI()
     m_pauseButton = KStdGameAction::pause(this, SLOT(pauseGame()), actionCollection());
     KStdGameAction::end(this, SLOT(closeGame()), actionCollection());
 
-    new KAction( i18n("&Select Image Folder..."), 0, this, SLOT(selectBackground()),
+    new KAction( i18n("&Select Background Folder..."), 0, this, SLOT(selectBackground()),
                        actionCollection(), "background_select" );
     m_backgroundShowAction =
-        new KToggleAction( i18n("Show &Images"), 0, this, SLOT(showBackground()),
+        new KToggleAction( i18n("Show &Backgrounds"), 0, this, SLOT(showBackground()),
                            actionCollection(), "background_show" );
+    m_backgroundShowAction->setCheckedState(i18n("Hide &Backgrounds"));
     m_backgroundShowAction->setEnabled( !m_backgroundDir.isEmpty() );
     m_backgroundShowAction->setChecked( m_showBackground );
 
-    KStdAction::keyBindings(this, SLOT(keyBindings()), actionCollection());
     m_soundAction = new KToggleAction( i18n("&Play Sounds"), 0, 0, 0, actionCollection(), "toggle_sound");
-
-    createStandardStatusBarAction();
-    setAutoSaveSettings("");
-    setStandardToolBarMenuEnabled(true);
-
-    createGUI();
 }
 
 void KJezzball::newGame()
@@ -312,7 +306,7 @@ QPixmap KJezzball::getBackgroundPixmap()
     if (dir.count() > 1)
     {
         // return random pixmap
-        int num = rand() % dir.count();
+        int num = kapp->random() % dir.count();
         return QPixmap( dir.absFilePath( dir[num] ) );
     }
     else if (dir.count()==1)
@@ -365,7 +359,7 @@ void KJezzball::second()
 
 void KJezzball::died()
 {
-    kdDebug() << "died" << endl;
+    kdDebug(12008) << "died" << endl;
     m_level.lifes--;
     m_lifesLCD->display( m_level.lifes );
     if ( m_level.lifes==0 ) gameOver();
@@ -439,6 +433,15 @@ void KJezzball::nextLevel()
 void KJezzball::switchLevel()
 {
     m_game.score += m_level.score;
+
+    // make sure the LCD provides enough digits for the score
+    // (fixes #96841)
+    int numDigits=0;
+    int temp_score = m_game.score;
+    for ( ; temp_score > 0; ++numDigits ) temp_score /= 10;
+    if ( numDigits < 5 ) numDigits = 5; // set numDigits to at least 5, otherwise it does not look well
+
+    m_scoreLCD->setNumDigits( numDigits );
     m_scoreLCD->display( m_game.score );
 
     QString score;
@@ -483,9 +486,4 @@ void KJezzball::highscore()
     d.exec();
 }
 
-void KJezzball::keyBindings()
-{
-    KKeyDialog::configure(actionCollection(), this);
-}
-
 #include "kbounce.moc"
