@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #ifndef KJEZZBALL_H_INCLUDED
@@ -24,6 +24,8 @@
 class JezzGame;
 class QLCDNumber;
 class QGridLayout;
+class KToggleAction;
+class KAction;
 
 class KJezzball : public KMainWindow
 {
@@ -31,23 +33,23 @@ class KJezzball : public KMainWindow
 
 public:
    KJezzball();
+   ~KJezzball();
 
 public slots:
    void newGame();
-   void pauseGame(); 
+   void pauseGame();
    void closeGame();
    void showHighscore();
    void selectBackground();
    void showBackground();
 
-protected slots:   
+protected slots:
    void died();
-   void newPercent( int percent ); 
+   void newPercent( int percent );
    void second();
    void switchLevel();
    void gameOverNow();
-   void keyBindings();
-      		
+
 protected:
    void createLevel( int level );
    void startLevel();
@@ -70,6 +72,8 @@ protected:
    QLCDNumber *m_scoreLCD;
    QLCDNumber *m_percentLCD;
    QLCDNumber *m_timeLCD;
+   KToggleAction *m_pauseButton, *m_backgroundShowAction, *m_soundAction;
+   KAction *m_newAction;
 
    QTimer *m_timer;
    QTimer *m_nextLevelTimer;
