@@ -26,8 +26,8 @@ const MainData MAIN_DATA = {
               "Japan) PuyoPuyo game"),
     "http://kfouleggs.sourceforge.net/",
     I18N_NOOP("Puyos"),
-    "2.1.9",
-    "2.1.9 (5 August 2004)"
+    "2.1.11",
+    "2.1.11 (12 September 2004)"
 };
 
 const uint HISTOGRAM_SIZE = 8;
