@@ -16,7 +16,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 **************************************************************************** */
 #include "kcubewidget.h"
@@ -237,7 +237,7 @@ void KCubeWidget::hint()
 void KCubeWidget::mouseReleaseEvent(QMouseEvent *e)
 {
   // only accept click if it was inside this cube
-  if(e->x()< 0 || e->x() > this->width() || e->y() < 0 || e->y() > this->height())
+  if(e->x()< 0 || e->x() > width() || e->y() < 0 || e->y() > height())
     return;
 
   if(e->button() == LeftButton && _clicksAllowed)
