@@ -1,6 +1,4 @@
 /***************************************************************************
-                          mwidget.h  -  description
-                             -------------------
     begin                : Fri May 19 2000
     copyright            : (C) 2000 by Roman Merzlyakov
     email                : roman@sbrf.barrt.ru
@@ -27,17 +25,21 @@
 #include "linesboard.h"
 #include "prompt.h"
 
+class BallPainter;
+
 class MainWidget : public QFrame
 {
   Q_OBJECT
   LinesBoard * lsb;
   LinesPrompt * lPrompt;
+  BallPainter *bPainter;
 
 public:
   MainWidget( QWidget* parent=0, const char* name=0 );
   ~MainWidget();
   LinesBoard * GetLsb();
   LinesPrompt * GetPrompt();
+  void updatePix();
 };
 
 #endif
