@@ -1,6 +1,6 @@
 /*
 
-    $Id: kmahjongg.cpp,v 1.91 2004/07/11 17:28:31 aacid Exp $
+    $Id: kmahjongg.cpp 401425 2005-03-28 21:52:58Z aacid $
 
     kmahjongg, the classic mahjongg game for KDE project
 
@@ -79,7 +79,6 @@ KMahjongg::KMahjongg( QWidget* parent, const char *name)
 
 
     bDemoModeActive = false;
-    bShowMatchingTiles = false;
 
     connect( bw, SIGNAL( statusTextChanged(const QString&, long) ),
                  SLOT( showStatusText(const QString&, long) ) );
@@ -146,6 +145,8 @@ void KMahjongg::setupKAction()
     demoAction = KStdGameAction::demo(this, SLOT(demoMode()), actionCollection());
     showMatchingTilesAction = new KToggleAction(i18n("Show &Matching Tiles"), 0, this, SLOT(showMatchingTiles()), actionCollection(), "options_show_matching_tiles");
     showMatchingTilesAction->setCheckedState(i18n("Hide &Matching Tiles"));
+    showMatchingTilesAction->setChecked(Prefs::showMatchingTiles());
+    bw->setShowMatch( Prefs::showMatchingTiles() );
     KStdGameAction::highscores(this, SLOT(showHighscores()), actionCollection());
     pauseAction = KStdGameAction::pause(this, SLOT(pause()), actionCollection());
 
@@ -158,7 +159,7 @@ void KMahjongg::setupKAction()
     redoAction = KStdGameAction::redo(this, SLOT(redo()), actionCollection());
 
     // edit
-    new KAction(i18n("&Board Editor..."), 0, this, SLOT(slotBoardEditor()), actionCollection(), "edit_board_editor");
+    new KAction(i18n("&Board Editor"), 0, this, SLOT(slotBoardEditor()), actionCollection(), "edit_board_editor");
 
     // settings
     KStdAction::preferences(this, SLOT(showSettings()), actionCollection());
@@ -265,9 +266,10 @@ void KMahjongg::pause()
 
 void KMahjongg::showMatchingTiles()
 {
-    bShowMatchingTiles = ! bShowMatchingTiles;
-    bw->setShowMatch( bShowMatchingTiles );
-    showMatchingTilesAction->setChecked(bShowMatchingTiles);
+    Prefs::setShowMatchingTiles(!Prefs::showMatchingTiles());
+    bw->setShowMatch( Prefs::showMatchingTiles() );
+    showMatchingTilesAction->setChecked(Prefs::showMatchingTiles());
+    Prefs::writeConfig();
 }
 
 void KMahjongg::showHighscores()
@@ -504,14 +506,20 @@ void KMahjongg::restartGame() {
     if( ! bDemoModeActive ) {
         bw->calculateNewGame(bw->getGameNum());
 
-	// initialise button states
-	bw->Game.allow_redo = bw->Game.allow_undo = 0;
+        // initialise button states
+        bw->Game.allow_redo = bw->Game.allow_undo = 0;
 
-	timerReset();
+        timerReset();
 
-    	// update the initial enabled/disabled state for
-    	// the menu and the tool bar.
-    	demoModeChanged(false);
+        // update the initial enabled/disabled state for
+        // the menu and the tool bar.
+        demoModeChanged(false);
+        if (is_paused)
+        {
+            pauseAction->setChecked(false);
+            is_paused = false;
+            bw->pause();
+        }
     }
 }
 
