@@ -14,9 +14,27 @@
 #include <kconfig.h>
 #include "version.h"
 
+
+// ================================================================
+//                         class MoveHint
+
+
+MoveHint::MoveHint(Card *card, Pile *to, bool d)
+{
+    m_card         = card;
+    m_to           = to;
+    m_dropiftarget = d;
+}
+
+
+// ================================================================
+//                    class DealerInfoList
+
+
 DealerInfoList *DealerInfoList::_self = 0;
 static KStaticDeleter<DealerInfoList> dl;
 
+
 DealerInfoList *DealerInfoList::self()
 {
     if (!_self)
@@ -29,6 +47,11 @@ void DealerInfoList::add(DealerInfo *dealer)
     list.append(dealer);
 }
 
+
+// ================================================================
+//                            class Dealer
+
+
 Dealer *Dealer::s_instance = 0;
 
 Dealer::Dealer( KMainWindow* _parent , const char* _name )
@@ -1106,19 +1129,20 @@ void Dealer::won()
     if (_won)
         return;
     _won = true;
-	 // update score, 'win' in demo mode also counts (keep it that way?)
-	 { // wrap in own scope to make KConfigGroupSave work
-    KConfig *config = kapp->config();
-    KConfigGroupSaver kcs(config, scores_group);
-	 unsigned int n = config->readUnsignedNumEntry(QString("won%1").arg(_id),0) + 1;
-	 config->writeEntry(QString("won%1").arg(_id),n);
-	 n = config->readUnsignedNumEntry(QString("winstreak%1").arg(_id),0) + 1;
-	 config->writeEntry(QString("winstreak%1").arg(_id),n);
-	 unsigned int m = config->readUnsignedNumEntry(QString("maxwinstreak%1").arg(_id),0);
-	 if (n>m)
-		 config->writeEntry(QString("maxwinstreak%1").arg(_id),n);
-	 config->writeEntry(QString("loosestreak%1").arg(_id),0);
-	 }
+
+    // update score, 'win' in demo mode also counts (keep it that way?)
+    { // wrap in own scope to make KConfigGroupSave work
+	KConfig *config = kapp->config();
+	KConfigGroupSaver kcs(config, scores_group);
+	unsigned int n = config->readUnsignedNumEntry(QString("won%1").arg(_id),0) + 1;
+	config->writeEntry(QString("won%1").arg(_id),n);
+	n = config->readUnsignedNumEntry(QString("winstreak%1").arg(_id),0) + 1;
+	config->writeEntry(QString("winstreak%1").arg(_id),n);
+	unsigned int m = config->readUnsignedNumEntry(QString("maxwinstreak%1").arg(_id),0);
+	if (n>m)
+	    config->writeEntry(QString("maxwinstreak%1").arg(_id),n);
+	config->writeEntry(QString("loosestreak%1").arg(_id),0);
+    }
 
     // sort cards by increasing z
     QCanvasItemList list = canvas()->allItems();
@@ -1144,8 +1168,10 @@ void Dealer::won()
             y = 3*canvas()->height()/2 - (kapp->random() % (canvas()->height() * 2));
             p.moveTopLeft(QPoint(x, y));
         } while (can.intersects(p));
-	    (*it).ptr->animatedMove( x, y, 0, STEPS_WON);
+
+	(*it).ptr->animatedMove( x, y, 0, STEPS_WON);
     }
+
     bool demo = demoActive();
     stopDemo();
     canvas()->update();
@@ -1329,7 +1355,7 @@ void Dealer::drawPile(KPixmap &pixmap, Pile *pile, bool selected)
     float s = -0.4;
     float n = -0.3;
 
-    int mid = (midColor().red() + midColor().green() + midColor().blue()) / 3;
+    int mid = QMAX( QMAX(midColor().red(), midColor().green()), midColor().blue());
 
     // if it's too dark - light instead of dark
     if (mid < 120) {
@@ -1372,10 +1398,6 @@ void Dealer::wheelEvent( QWheelEvent *e )
     }
 }
 
-MoveHint::MoveHint(Card * c, Pile *_to, bool d)
-{
-    _card = c; to = _to; _dropiftarget = d;
-}
 
 void Dealer::countLoss()
 {
