@@ -22,7 +22,6 @@
 #include "freecell.h"
 #include <klocale.h>
 #include "deck.h"
-#include "pile.h"
 #include <assert.h>
 #include <kdebug.h>
 #include <stdio.h>
@@ -30,7 +29,8 @@
 #include <qtimer.h>
 #include "cardmaps.h"
 
-#include <freecell-solver/fcs_user.h>
+#include "freecell-solver/fcs_user.h"
+#include "freecell-solver/fcs_cl.h"
 
 const int CHUNKSIZE = 100;
 
@@ -40,7 +40,10 @@ void FreecellPile::moveCards(CardList &c, Pile *to)
         Pile::moveCards(c, to);
         return;
     }
-    dynamic_cast<FreecellBase*>(dealer())->moveCards(c, this, to);
+    FreecellBase *b = dynamic_cast<FreecellBase*>(dealer());
+    if (b) {
+        b->moveCards(c, this, to);
+    }
 }
 
 //-------------------------------------------------------------------------//
@@ -76,12 +79,20 @@ unlimited_move(unlimit)
         t = new Pile(1 + stores + freecells +i, this);
         target.append(t);
         t->setType(Pile::KlondikeTarget);
-        t->setRemoveFlags(Pile::Default);
+        // COOLO: I'm still not too sure about that t->setRemoveFlags(Pile::Default);
     }
 
     setActions(Dealer::Demo | Dealer::Hint);
 }
 
+FreecellBase::~FreecellBase()
+{
+    if (solver_instance)
+    {
+        freecell_solver_user_free(solver_instance);
+        solver_instance = NULL;
+    }
+}
 //-------------------------------------------------------------------------//
 
 void FreecellBase::restart()
@@ -136,6 +147,66 @@ int getDeck(Card::Suits suit)
     return 0;
 }
 
+static const char * freecell_solver_cmd_line_args[280] =
+{
+"--method", "soft-dfs", "-to", "0123456789", "-step",
+"500", "--st-name", "1", "-nst", "--method",
+"soft-dfs", "-to", "0123467", "-step", "500",
+"--st-name", "2", "-nst", "--method", "random-dfs",
+"-seed", "2", "-to", "0[01][23456789]", "-step",
+"500", "--st-name", "3", "-nst", "--method",
+"random-dfs", "-seed", "1", "-to", "0[0123456789]",
+"-step", "500", "--st-name", "4", "-nst", "--method",
+"random-dfs", "-seed", "3", "-to", "0[01][23467]",
+"-step", "500", "--st-name", "5", "-nst", "--method",
+"random-dfs", "-seed", "4", "-to", "0[0123467]",
+"-step", "500", "--st-name", "9", "-nst", "--method",
+"random-dfs", "-to", "[01][23456789]", "-seed", "8",
+"-step", "500", "--st-name", "10", "-nst",
+"--method", "random-dfs", "-to", "[01][23456789]",
+"-seed", "268", "-step", "500", "--st-name", "12",
+"-nst", "--method", "a-star", "-asw",
+"0.2,0.3,0.5,0,0", "-step", "500", "--st-name", "16",
+"-nst", "--method", "a-star", "-to", "0123467",
+"-asw", "0.5,0,0.3,0,0", "-step", "500", "--st-name",
+"18", "-nst", "--method", "soft-dfs", "-to",
+"0126394875", "-step", "500", "--st-name", "19",
+"--prelude",
+"350@2,350@5,350@9,350@12,350@2,350@10,350@3,350@9,350@5,350@18,350@2,350@5,350@4,350@10,350@4,350@12,1050@9,700@18,350@10,350@5,350@2,350@10,1050@16,350@2,700@4,350@10,1050@2,1400@3,350@18,1750@5,350@16,350@18,700@4,1050@12,2450@5,1400@18,1050@2,1400@10,6300@1,4900@12,8050@18",
+"-ni", "--method", "soft-dfs", "-to", "01ABCDE",
+"-step", "500", "--st-name", "0", "-nst", "--method",
+"random-dfs", "-to", "[01][ABCDE]", "-seed", "1",
+"-step", "500", "--st-name", "1", "-nst", "--method",
+"random-dfs", "-to", "[01][ABCDE]", "-seed", "2",
+"-step", "500", "--st-name", "2", "-nst", "--method",
+"random-dfs", "-to", "[01][ABCDE]", "-seed", "3",
+"-step", "500", "--st-name", "3", "-nst", "--method",
+"random-dfs", "-to", "01[ABCDE]", "-seed", "268",
+"-step", "500", "--st-name", "4", "-nst", "--method",
+"a-star", "-to", "01ABCDE", "-step", "500",
+"--st-name", "5", "-nst", "--method", "a-star",
+"-to", "01ABCDE", "-asw", "0.2,0.3,0.5,0,0", "-step",
+"500", "--st-name", "6", "-nst", "--method",
+"a-star", "-to", "01ABCDE", "-asw", "0.5,0,0.5,0,0",
+"-step", "500", "--st-name", "7", "-nst", "--method",
+"random-dfs", "-to", "[01][ABD][CE]", "-seed", "1900",
+"-step", "500", "--st-name", "8", "-nst", "--method",
+"random-dfs", "-to", "[01][ABCDE]", "-seed", "192",
+"-step", "500", "--st-name", "9", "-nst", "--method",
+"random-dfs", "-to", "[01ABCDE]", "-seed", "1977",
+"-step", "500", "--st-name", "10", "-nst",
+"--method", "random-dfs", "-to", "[01ABCDE]", "-seed",
+"24", "-step", "500", "--st-name", "11", "-nst",
+"--method", "soft-dfs", "-to", "01ABDCE", "-step",
+"500", "--st-name", "12", "-nst", "--method",
+"soft-dfs", "-to", "ABC01DE", "-step", "500",
+"--st-name", "13", "-nst", "--method", "soft-dfs",
+"-to", "01EABCD", "-step", "500", "--st-name", "14",
+"-nst", "--method", "soft-dfs", "-to", "01BDAEC",
+"-step", "500", "--st-name", "15", "--prelude",
+"1000@0,1000@3,1000@0,1000@9,1000@4,1000@9,1000@3,1000@4,2000@2,1000@0,2000@1,1000@14,2000@11,1000@14,1000@3,1000@11,1000@2,1000@0,2000@4,2000@10,1000@0,1000@2,2000@10,1000@0,2000@11,2000@1,1000@10,1000@2,1000@10,2000@0,1000@9,1000@1,1000@2,1000@14,3000@8,1000@2,1000@14,1000@1,1000@10,3000@6,2000@4,1000@2,2000@0,1000@2,1000@11,2000@6,1000@0,5000@1,1000@0,2000@1,1000@2,3000@3,1000@10,1000@14,2000@6,1000@0,1000@2,2000@11,6000@8,8000@9,3000@1,2000@10,2000@14,3000@15,4000@0,1000@8,1000@10,1000@14,7000@0,14000@2,6000@3,7000@4,1000@8,4000@9,2000@15,2000@6,4000@3,2000@4,3000@15,2000@0,6000@1,2000@4,4000@6,4000@9,4000@14,7000@8,3000@0,3000@1,5000@2,3000@3,4000@9,8000@10,9000@3,5000@8,7000@11,11000@12,12000@0,8000@3,11000@9,9000@15,7000@2,12000@8,16000@5,8000@13,18000@0,9000@15,12000@10,16000@0,14000@3,16000@9,26000@4,23000@3,42000@6,22000@8,27000@10,38000@7,41000@0,42000@3,84000@13,61000@15,159000@5,90000@9"
+};
+
 void FreecellBase::findSolution()
 {
     kdDebug(11111) << "findSolution\n";
@@ -143,15 +214,42 @@ void FreecellBase::findSolution()
     QString output = solverFormat();
     kdDebug(11111) << output << endl;
 
-    solver_instance = freecell_solver_user_alloc();
+    int ret;
 
-    freecell_solver_user_set_solving_method(solver_instance,
-                                            FCS_METHOD_SOFT_DFS);
+    /* If solver_instance was not initialized yet - initialize it */
+    if (! solver_instance)
+    {
+        solver_instance = freecell_solver_user_alloc();
 
-    freecell_solver_user_set_solution_optimization(solver_instance,
-                                                   1);
+        char * error_string;
+        int error_arg;
+        char * known_parameters[1] = {NULL};
 
-    int ret = freecell_solver_user_set_game(solver_instance,
+
+        ret = freecell_solver_user_cmd_line_parse_args(
+            solver_instance,
+            sizeof(freecell_solver_cmd_line_args)/sizeof(freecell_solver_cmd_line_args[0]),
+            freecell_solver_cmd_line_args,
+            0,
+            known_parameters,
+            NULL,
+            NULL,
+            &error_string,
+            &error_arg
+            );
+
+
+        assert(!ret);
+    }
+    /*
+     * I'm using the more standard interface instead of the depracated
+     * user_set_game one. I'd like that each function will have its
+     * own dedicated purpose.
+     *
+     *     Shlomi Fish
+     * */
+#if 0
+    ret = freecell_solver_user_set_game(solver_instance,
                                             freecell.count(),
                                             store.count(),
                                             deck->decksNum(),
@@ -159,6 +257,15 @@ void FreecellBase::findSolution()
                                             unlimited_move,
                                             es_filling);
     assert(!ret);
+#else
+    freecell_solver_user_set_num_freecells(solver_instance,freecell.count());
+    freecell_solver_user_set_num_stacks(solver_instance,store.count());
+    freecell_solver_user_set_num_decks(solver_instance,deck->decksNum());
+    freecell_solver_user_set_sequences_are_built_by_type(solver_instance, FCS_SEQ_BUILT_BY_ALTERNATE_COLOR);
+    freecell_solver_user_set_sequence_move(solver_instance, unlimited_move);
+    freecell_solver_user_set_empty_stacks_filled_by(solver_instance, es_filling);
+
+#endif
 
     freecell_solver_user_limit_iterations(solver_instance, CHUNKSIZE);
 
@@ -294,9 +401,130 @@ QString FreecellBase::solverFormat() const
     return output;
 }
 
+//  Idea stolen from klondike.cpp
+//
+//  This function returns true when it is certain that the card t is no longer
+//  needed on any of the play piles.
+//
+//  To determine wether a card is no longer needed on any of the play piles we
+//  obviously must know what a card can be used for there. According to the
+//  rules a card can be used to store another card with 1 less unit of value
+//  and opposite color. This is the only thing that a card can be used for
+//  there. Therefore the cards with lowest value (1) are useless there (base
+//  case). The other cards each have 2 cards that can be stored on them, let us
+//  call those 2 cards *depending cards*.
+//
+//  The object of the game is to put all cards on the target piles. Therefore
+//  cards that are no longer needed on any of the play piles should be put on
+//  the target piles if possible. Cards on the target piles can not be moved
+//  and they can not store any of its depending cards. Let us call this that
+//  the cards on the target piles are *out of play*.
+//
+//  The simple and obvious rule is:
+//    A card is no longer needed when both of its depending cards are out of
+//    play.
+//
+//  More complex:
+//    Assume card t is red.  Now, if the lowest unplayed black card is
+//    t.value()-2, then t may be needed to hold that black t.value()-1 card.
+//    If the lowest unplayed black card is t.value()-1, it will be playable
+//    to the target, unless it is needed for a red card of value t.value()-2.
+//
+//  So, t is not needed if the lowest unplayed red card is t.value()-2 and the
+//  lowest unplayed black card is t.value()-1, OR if the lowest unplayed black
+//  card is t.value().  So, no recursion needed - we did it ahead of time.
+
+bool FreecellBase::noLongerNeeded(const Card & t)
+{
+
+    if (t.value() <= Card::Two) return true; //  Base case.
+
+    bool cardIsRed = t.isRed();
+
+    uint numSame = 0, numDiff = 0;
+    Card::Values lowSame = Card::King, lowDiff = Card::King;
+    for (PileList::Iterator it = target.begin(); it != target.end(); ++it)
+    {
+        if ((*it)->isEmpty())
+            continue;
+        if ((*it)->top()->isRed() == cardIsRed) {
+            numSame++;
+            if ((*it)->top()->value() < lowSame)
+                lowSame = static_cast<Card::Values>((*it)->top()->value()+1);
+        } else {
+            numDiff++;
+            if ((*it)->top()->value() < lowDiff)
+                lowDiff = static_cast<Card::Values>((*it)->top()->value()+1);
+        }
+    }
+    if (numSame < target.count()/2) lowSame = Card::Ace;
+    if (numDiff < target.count()/2) lowDiff = Card::Ace;
+
+    return (lowDiff >= t.value() ||
+        (lowDiff >= t.value()-1 && lowSame >= t.value()-2));
+}
+
+//  This is the getHints() from dealer.cpp with one line changed
+//  to use noLongerNeeded() to decide if the card should be
+//  dropped or not.
+//
+//  I would recommend adding a virtual bool noLongerNeeded(const Card &t)
+//  to the base class (Dealer) that just returns true, and then calling
+//  it like is done here.  That would preserve current functionality
+//  but eliminate this code duplication
 void FreecellBase::getHints()
 {
-    Dealer::getHints();
+    for (PileList::Iterator it = piles.begin(); it != piles.end(); ++it)
+    {
+        if (!takeTargetForHints() && (*it)->target())
+            continue;
+
+        Pile *store = *it;
+        if (store->isEmpty())
+            continue;
+//        kdDebug(11111) << "trying " << store->top()->name() << endl;
+
+        CardList cards = store->cards();
+        while (cards.count() && !cards.first()->realFace()) cards.remove(cards.begin());
+
+        CardList::Iterator iti = cards.begin();
+        while (iti != cards.end())
+        {
+            if (store->legalRemove(*iti)) {
+//                kdDebug(11111) << "could remove " << (*iti)->name() << endl;
+                for (PileList::Iterator pit = piles.begin(); pit != piles.end(); ++pit)
+                {
+                    Pile *dest = *pit;
+                    if (dest == store)
+                        continue;
+                    if (store->indexOf(*iti) == 0 && dest->isEmpty() && !dest->target())
+                        continue;
+                    if (!dest->legalAdd(cards))
+                        continue;
+
+                    bool old_prefer = checkPrefering( dest->checkIndex(), dest, cards );
+                    if (!takeTargetForHints() && dest->target())
+                        newHint(new MoveHint(*iti, dest, noLongerNeeded(*(*iti))));
+                    else {
+                        store->hideCards(cards);
+                        // if it could be here as well, then it's no use
+                        if ((store->isEmpty() && !dest->isEmpty()) || !store->legalAdd(cards))
+                            newHint(new MoveHint(*iti, dest));
+                        else {
+                            if (old_prefer && !checkPrefering( store->checkIndex(),
+                                                               store, cards ))
+                            { // if checkPrefers says so, we add it nonetheless
+                                newHint(new MoveHint(*iti, dest));
+                            }
+                        }
+                        store->unhideCards(cards);
+                    }
+                }
+            }
+            cards.remove(iti);
+            iti = cards.begin();
+        }
+    }
 }
 
 void FreecellBase::demo()
@@ -307,8 +535,8 @@ void FreecellBase::demo()
     }
     towait = (Card*)-1;
     unmarkAll();
-    kdDebug(11111) << "demo " << (!solver_instance && solver_ret != FCS_STATE_IS_NOT_SOLVEABLE) << endl;
-    if (!solver_instance && solver_ret != FCS_STATE_IS_NOT_SOLVEABLE)
+    kdDebug(11111) << "demo " << (solver_ret != FCS_STATE_IS_NOT_SOLVEABLE) << endl;
+    if (solver_ret != FCS_STATE_IS_NOT_SOLVEABLE)
         findSolution();
 }
 
@@ -349,9 +577,7 @@ void FreecellBase::freeSolution()
 
     if (!solver_instance)
         return;
-    freecell_solver_user_free(solver_instance);
-
-    solver_instance = 0;
+    freecell_solver_user_recycle(solver_instance);
     solver_ret = FCS_STATE_NOT_BEGAN_YET;
 }
 
