@@ -58,21 +58,33 @@ public slots:
     void gameLost();
     void changeWallpaper();
     void slotGameInfo(const QString &);
+    void slotSetMoves( int moves );
     void helpGame();
     void enableAutoDrop();
+	 void showStats();
 
 private:
+    void setGameCaption();
     void setBackSide(const QString &deck, const QString &dir);
     virtual void showEvent(QShowEvent *e);
 
-    Dealer* dill;
-    KSelectAction *games, *wallpapers;
-    KAction *backs, *undo;
-    KToggleAction *animation, *dropaction;
-    QPixmap background;
-    QColor midcolor;
-    QStringList wallpaperlist;
-    KRecentFilesAction *recent;
+private:
+    // Members
+
+    Dealer         *dill;	// The current patience
+
+    KSelectAction  *games;
+    KSelectAction  *wallpapers;
+    KAction        *backs;
+    KAction        *undo;
+    KToggleAction  *animation;
+    KToggleAction  *dropaction;
+    KAction        *stats;
+
+    QPixmap         background;
+    QColor          midcolor;
+    QStringList     wallpaperlist;
+    KRecentFilesAction  *recent;
 };
 
 #endif
