@@ -56,6 +56,9 @@ PokerGame::PokerGame(KRandomSequence *random)
 {
   // We don't need to save if we just started.
   m_isDirty = false;
+
+  // Some defaults.
+  m_type = SinglePlayer;
 }
 
 
@@ -63,8 +66,6 @@ PokerGame::~PokerGame()
 {
   m_activePlayers.clear();
   m_removedPlayers.clear();
-
-  delete[] m_players;
 }
 
 
@@ -84,14 +85,66 @@ PokerGame::dealCards(PokerPlayer *player, bool skip[])
 }
 
 
+void
+PokerGame::activatePlayer(PokerPlayer *player)
+{
+  if (!m_activePlayers.contains(player)) {
+    m_activePlayers.append(player);
+    m_removedPlayers.remove(player);
+  }
+}
+
+
+void
+PokerGame::inactivatePlayer(PokerPlayer *player)
+{
+  if (m_activePlayers.contains(player)) {
+    m_activePlayers.remove(player);
+    m_removedPlayers.append(player);
+  }
+}
+
+
+void
+PokerGame::newGame(PokerGameType type, 
+		   int numPlayers, PokerPlayer *players,
+		   int minBet, int maxBet)
+{
+  m_type = type;
+
+  // Store the players.  These are never changed in the current implementation.
+  m_numPlayers = numPlayers;
+  m_players    = players;
+
+  setBettingLimits(minBet, maxBet);
+
+  setState(StateStartRound);
+
+  // Initiate player arrays. Make all players active from the start.
+  m_activePlayers.clear();
+  m_removedPlayers.clear();
+  for (unsigned int i = 0; i < m_numPlayers; i++)
+    m_activePlayers.append(&m_players[i]);
+
+  // Inform players how much they may bet.
+  for (unsigned int i = 0; i < m_activePlayers.count(); i++)
+    m_activePlayers.at(i)->setBetDefaults(m_minBet, m_maxBet);
+}
+
+
 void
 PokerGame::newRound()
 {
+  // Reset the pot to zero.
   m_pot = 0;
 
-  // Collect the cards and mix them.
+  // Collect the cards and shuffle them.
   m_deck.reset();
-  m_deck.mix();
+  m_deck.shuffle();
+
+  // Clear the list of active and removed players.
+  m_activePlayers.clear();
+  m_removedPlayers.clear();
 }
 
 
@@ -114,6 +167,19 @@ kpok::kpok(QWidget *parent, const char *name)
 
   m_random.setSeed(0);
   
+  // This class owns the players.  Create them here.
+  // Currently we always allocate two - one human and one computer.
+  m_numPlayers = 2;		// FIXME: Hard coded!!
+  m_players    = new PokerPlayer[m_numPlayers];
+
+  // Initialize the first one to human...
+  m_players[0].setHuman();
+  m_players[0].setName(i18n("You"));
+
+  // ...and the rest to computer players.
+  for (int unsigned i = 1; i < m_numPlayers; i++)
+    m_players[i].setName(QString("Computer %1").arg(i-1));
+
   lastHandText = "";
 
   version = kapp->caption() + " " + KPOKER_VERSION;
@@ -135,22 +201,24 @@ kpok::kpok(QWidget *parent, const char *name)
 kpok::~kpok()
 {
   if (mOptions != 0) {
-    if (m_game.m_activePlayers.count() + m_game.m_removedPlayers.count() > 1) {
-      m_game.m_minBet = mOptions->getMinBet();
-      m_game.m_maxBet = mOptions->getMaxBet();
-    }
+    if (m_numPlayers > 1)
+      m_game.setBettingLimits(mOptions->getMinBet(), mOptions->getMaxBet());
+
     drawDelay = mOptions->getDrawDelay();
     //	cashPerRound = mOptions->getCashPerRound(); // NOT(!) configurable
   }
 
   KConfig* conf = kapp->config();
   conf->setGroup("General");
-  conf->writeEntry("MaxBet", m_game.m_maxBet);
-  conf->writeEntry("MinBet", m_game.m_minBet);
+  conf->writeEntry("MinBet", m_game.getMinBet());
+  conf->writeEntry("MaxBet", m_game.getMaxBet());
   // conf->writeEntry("CashPerRound", cashPerRound);
   conf->writeEntry("DrawDelay", drawDelay);
 
-  for (int i = 0; i < m_game.getNumPlayers(); i++)
+
+  delete[] m_players;
+
+  for (unsigned int i = 0; i < m_numPlayers; i++)
     delete playerBox[i];
   delete[] playerBox;
 
@@ -164,7 +232,9 @@ kpok::~kpok()
 
 void kpok::initWindow()
 {
-  blinking = true;
+  m_blinking    = true;
+  m_blinkStat   = 0;
+  m_blinkingBox = 0;
 
   // General font stuff.  Define myFixedFont and wonFont.
   QFont myFixedFont;
@@ -184,7 +254,7 @@ void kpok::initWindow()
 
   // The draw button
   drawButton = new QPushButton(this);
-  drawButton->setText(i18n("&Draw"));
+  drawButton->setText(i18n("&Deal"));
   connect(drawButton, SIGNAL(clicked()), this, SLOT(drawClick()));
   inputLayout->addWidget(drawButton);
   inputLayout->addStretch(1);
@@ -209,7 +279,7 @@ void kpok::initWindow()
   wonLabel->hide();
   inputLayout->addStretch(1);
 
-  // The pot
+  // The pot view
   potLabel = new QLabel(this);
   potLabel->setFont(myFixedFont);
   potLabel->setFrameStyle(QFrame::WinPanel | QFrame::Sunken);
@@ -222,7 +292,6 @@ void kpok::initWindow()
   // Timers
   blinkTimer = new QTimer(this);
   connect( blinkTimer, SIGNAL(timeout()), SLOT(bTimerEvent()) );
-  blinkStat=0;
 
   waveTimer = new QTimer(this);
   connect( waveTimer, SIGNAL(timeout()), SLOT(waveTimerEvent()) );
@@ -238,7 +307,7 @@ void kpok::initWindow()
   connect(betBox, SIGNAL(fold()),          this, SLOT(out()));
 
   // some tips 
-  QToolTip::add(drawButton, i18n("Draw new cards"));
+  QToolTip::add(drawButton, i18n("Continue the round"));
   QToolTip::add(potLabel, i18n("The current pot"));
 
   // Load all cards into pixmaps first -> in the constructor.
@@ -260,8 +329,6 @@ void kpok::initWindow()
     cardImages->loadCards(conf->readPathEntry("CardPath",
 				  KCardDialog::getDefaultCardDir()));
   }
-
-  blinkingBox = 0;
 }
 
 
@@ -271,6 +338,7 @@ void kpok::newGame()
 {
   NewGameDlg* newGameDlg;
 
+  // Get a "New Game" dialog.
   lastHandText = "";
   newGameDlg = new NewGameDlg(this);
   newGameDlg->hideReadingFromConfig();
@@ -280,27 +348,22 @@ void kpok::newGame()
     stopDrawing();
     stopWave();
 
-    int players = DEFAULT_PLAYERS;
-
-    // Delete the old values
-    for (int i = 0; i < m_game.getNumPlayers(); i++)
+    // Delete the old values.
+    for (unsigned int i = 0; i < m_numPlayers; i++)
       delete playerBox[i];
-    delete[] m_game.m_players;
     delete[] playerBox;// necessary?
 
-    m_game.m_activePlayers.clear();
-    m_game.m_removedPlayers.clear();
+    int numPlayers = newGameDlg->getPlayers();
 
-    players = newGameDlg->getPlayers();
-
-    //most things will be done in initPoker
-    initPoker(players);
+    // Most things will be done in initPoker.
+    initPoker(numPlayers);
 
     // Set/show the name and money of all players.
-    for (int unsigned i = 0; i < m_game.m_activePlayers.count(); i++){
-      m_game.m_activePlayers.at(i)->setName(newGameDlg->name(i));
+    for (unsigned int i = 0; i < m_numPlayers; i++) {
+      m_players[i].setName(newGameDlg->name(i));
       playerBox[i]->showName();
-      m_game.m_activePlayers.at(i)->setCash((newGameDlg->money() >= m_game.m_minBet) ? newGameDlg->money() : START_MONEY);
+      m_players[i].setCash((newGameDlg->money() >= m_game.getMinBet())
+			   ? newGameDlg->money() : START_MONEY);
       m_game.setDirty();
     }
 
@@ -308,7 +371,7 @@ void kpok::newGame()
     paintCash();
 
     // Activate the Draw button.
-    drawButton->setText(i18n("&Draw"));
+    drawButton->setText(i18n("&Deal"));
     drawButton->setEnabled(true);
   }
 
@@ -324,37 +387,34 @@ void kpok::newRound()
 
   playerBox[0]->setHeldEnabled(false);
 
-  int players = m_game.m_activePlayers.count() + m_game.m_removedPlayers.count();
-  if (players == 1)
+  if (m_numPlayers == 1)
     onePlayerGame = true;
 
   readOptions(); // maybe some options have changed so check em
-  m_game.m_activePlayers.clear();
-  m_game.m_removedPlayers.clear();
 
-  if (m_game.m_players[0].getCash() < m_game.m_minBet)
+  if (m_players[0].getCash() < m_game.getMinBet())
     noMoney();
   else {
-    for (int i = 0; i < players; i++) {
-      if (m_game.m_players[i].getCash() >= m_game.m_minBet)
-	m_game.m_activePlayers.append(&m_game.m_players[i]);
+    for (unsigned int i = 0; i < m_numPlayers; i++) {
+      if (m_players[i].getCash() >= m_game.getMinBet())
+	m_game.activatePlayer(&m_players[i]);
       else
-	removePlayerFromRound(&m_game.m_players[i]);
+	removePlayerFromRound(&m_players[i]);
     }
   }
 
-  if (m_game.m_activePlayers.count() == 1 && !onePlayerGame)
+  if (m_game.getNumActivePlayers() == 1 && m_game.getType() != SinglePlayer)
     switchToOnePlayerRules();
 
-  blinkingBox = 0;
+  m_blinkingBox = 0;
   wonLabel->hide();
   stopBlinking();
   stopWave();
 
-  for (int unsigned i = 0; i < m_game.m_activePlayers.count(); i++)
-    m_game.m_activePlayers.at(i)->newRound();
+  for (int i = 0; i < m_game.getNumActivePlayers(); i++)
+    m_game.getActivePlayer(i)->newRound();
 
-  // We are beginning a new round so every card is available
+  // We are beginning a new round so every card is available.
   drawAllDecks();
   playerBox[0]->showHelds(false);
 
@@ -363,16 +423,16 @@ void kpok::newRound()
   for (int i = 0; i < PokerHandSize; i++)
     skip[i] = false;
 
-  for (int unsigned i = 0; i < m_game.m_activePlayers.count(); i++)
-    drawCards(m_game.m_activePlayers.at(i), skip);
+  for (int i = 0; i < m_game.getNumActivePlayers(); i++)
+    drawCards(m_game.getActivePlayer(i), skip);
 
-  if (m_game.m_activePlayers.count() > 1) {
-    findHumanPlayer()->changeBet(m_game.m_minBet);
-    m_game.bet(m_game.m_minBet);
+  if (m_game.getNumActivePlayers() > 1) {
+    findHumanPlayer()->changeBet(m_game.getMinBet());
+    m_game.bet(m_game.getMinBet());
     betBox->show();
   }
   else {
-    m_game.m_activePlayers.at(0)->changeBet(cashPerRound);
+    m_game.getActivePlayer(0)->changeBet(cashPerRound);
     betBox->hide();
   }
 
@@ -392,35 +452,35 @@ void kpok::bet()
 
   bool raised = false;
   int oldMustBet = 0;
-  if (m_game.getState() == StateRaise)
+  if (m_game.getState() == StateBet2)
     oldMustBet = currentMustBet;
 
-  if (m_game.getState() == StateBet || m_game.getState() == StateRaise) {
+  if (m_game.getState() == StateBet1 || m_game.getState() == StateBet2) {
     // The betting has just begun.  This can be either the first or
-    // the second betting phase (state == StateBet or StateRaise).
+    // the second betting phase (state == StateBet1 or StateBet2).
     // FIXME: These state names must be changed!
 
     // Find out how much the other players must bet.
     currentMustBet = findHumanPlayer()->getCurrentBet(); 
 
     // First bet as usual.
-    for (int unsigned i = 0; i < m_game.m_activePlayers.count(); i++) {
-      PokerPlayer *player    = m_game.m_activePlayers.at(i);
+    for (int i = 0; i < m_game.getNumActivePlayers(); i++) {
+      PokerPlayer *player    = m_game.getActivePlayer(i);
       int          playerBet = 0;
 
       if (player->getHuman()) 
 	continue;
 
-      if (m_game.getState() == StateBet) // first bet phase
+      if (m_game.getState() == StateBet1) // first bet phase
 	playerBet = player->bet(currentMustBet);
-      else if (m_game.getState() == StateRaise) // 2nd bet phase
+      else if (m_game.getState() == StateBet2) // 2nd bet phase
 	playerBet = player->raise(currentMustBet);
 
       if (playerBet < currentMustBet) {
 	removePlayerFromRound(player);
 	// FIXME: This should be bet from the beginning!
-	if (m_game.getState() == StateBet)
-	  m_game.bet(m_game.m_minBet);
+	if (m_game.getState() == StateBet1)
+	  m_game.bet(m_game.getMinBet());
 	i--;
       }
       else {
@@ -434,13 +494,13 @@ void kpok::bet()
       }
     }
   }
-  else if (m_game.getState() == StateContinueBet
-	   || m_game.getState() == StateContinueRaise) {
+  else if (m_game.getState() == StateRaise1
+	   || m_game.getState() == StateRaise2) {
 
     // The bet has been raised.
     paintCash();
-    for (unsigned int i = 0; i < m_game.m_activePlayers.count(); i++) {
-      PokerPlayer *player    = m_game.m_activePlayers.at(i);
+    for (int i = 0; i < m_game.getNumActivePlayers(); i++) {
+      PokerPlayer *player  = m_game.getActivePlayer(i);
 
       // human player
       if (player->getCurrentBet() < currentMustBet && player->getHuman()) {
@@ -454,12 +514,12 @@ void kpok::bet()
 
 
   oldBet_raise = findHumanPlayer()->getCurrentBet(); // used by out() only
-  if (m_game.getState() == StateBet || m_game.getState() == StateRaise) {
+  if (m_game.getState() == StateBet1 || m_game.getState() == StateBet2) {
     if (raised) {
-      if (m_game.getState() == StateBet)
-	m_game.setState(StateContinueBet);
+      if (m_game.getState() == StateBet1)
+	m_game.setState(StateRaise1);
       else
-	m_game.setState(StateContinueRaise);
+	m_game.setState(StateRaise2);
 
       if (adjust)
 	adjustBet();
@@ -473,19 +533,19 @@ void kpok::bet()
 	emit statusBarMessage(i18n("Clicking on draw means you are out"));
     }
     else {
-      if (m_game.getState() == StateBet)
+      if (m_game.getState() == StateBet1)
 	m_game.setState(StateExchangeCards);
       else
 	m_game.setState(StateSee);
     }
   }
-  else if (m_game.getState() == StateContinueBet && !raised) {
+  else if (m_game.getState() == StateRaise1 && !raised) {
     emit clearStatusBar();
     //	weWillAdjustLabel->hide();
     betBox->stopRaise();
     m_game.setState(StateExchangeCards);
   }
-  else if (m_game.getState() == StateContinueRaise && !raised) {
+  else if (m_game.getState() == StateRaise2 && !raised) {
     emit clearStatusBar();
     //	weWillAdjustLabel->hide();
     betBox->stopRaise();
@@ -501,9 +561,9 @@ void kpok::bet()
   // don't continue game if player 1 is alone
   // TODO: port to players > 2
   // this is ONLY working for players <= 2
-  if (m_game.m_removedPlayers.count() >= 1 
-      && m_game.m_activePlayers.count() == 1)
-    displayWinner_Computer(m_game.m_activePlayers.at(0), true);
+  if (m_game.getNumInactivePlayers() >= 1 
+      && m_game.getNumActivePlayers() == 1)
+    displayWinner_Computer(m_game.getActivePlayer(0), true);
 }
 
 
@@ -520,7 +580,7 @@ void kpok::out()
   // Go to next state immediately.  (Previously we told the user to
   // click the action button.)
   drawClick();
-  //drawButton->setText(i18n("&Draw"));
+  //drawButton->setText(i18n("&End Round"));
 }
 
 
@@ -538,77 +598,61 @@ void kpok::adjustBet()
 // This is called from newGame(), readEntriesAndInitPoker(), loadGame().
 //
 
-void kpok::initPoker(int numPlayers, PokerPlayer* ownAllPlayers)
+void kpok::initPoker(unsigned int numPlayers)
 {
-  m_game.m_numPlayers = numPlayers;
+  m_numPlayers = numPlayers;
 
-  // read some defaults
+  // Tell the game about the players also.
+  PokerGameType gametype = (numPlayers == 1) ? SinglePlayer : MultiPlayer;
+
+  // Read some defaults.
   kapp->config()->setGroup("General");
-  m_game.m_minBet = kapp->config()->readNumEntry("MinBet", MIN_BET);
-  m_game.m_maxBet = kapp->config()->readNumEntry("MaxBet", MAX_BET);
+  int  minBet = kapp->config()->readNumEntry("MinBet", MIN_BET);
+  int  maxBet = kapp->config()->readNumEntry("MaxBet", MAX_BET);
 
-  // NOT(!) configurable
+  // Start a new poker game using the data found out above.
+  m_game.newGame(gametype, m_numPlayers, m_players, minBet, maxBet);
+
+  // Not (yet) configurable
   cashPerRound = CASH_PER_ROUND;
   drawDelay = kapp->config()->readNumEntry("DrawDelay", DRAWDELAY);
 
-  blinkingBox = 0;
-  m_game.setState(StateStartRound);
-  currentMustBet = m_game.m_minBet;
+  m_blinkingBox = 0;
+  currentMustBet = m_game.getMinBet();
 
-  // Init the players first.
-  // We use a QPtrList to access the players.
-  m_game.m_activePlayers.clear();
-  m_game.m_removedPlayers.clear();
+  // --- Graphics ---
 
-  // Create an array of PokerPlayers if we didn't get any through the call.
-  if (ownAllPlayers == 0) {
-    m_game.m_players = new PokerPlayer[numPlayers];
-    for (int i = 0; i < numPlayers; i++)
-      m_game.m_activePlayers.append(&m_game.m_players[i]);
-    m_game.m_activePlayers.at(0)->setHuman();
-    m_game.m_activePlayers.at(0)->setName(i18n("You"));
-    for (int unsigned i = 1; i < m_game.m_activePlayers.count(); i++) {
-      m_game.m_activePlayers.at(i)->setName(QString("Computer %1").arg(i-1));
-    }
-  }
-  else {
-    // There has someone an own version of m_players so lets use it!
-    m_game.m_players = ownAllPlayers;
-    for (int i = 0; i < numPlayers; i++)
-      m_game.m_activePlayers.append(&m_game.m_players[i]);
-  }
+  // Make all labels / boxes / cardwidgets for every player.
+  playerBox = new PlayerBox *[numPlayers];
 
-  // Inform players how much they may bet.
-  for (int unsigned i = 0; i < m_game.m_activePlayers.count(); i++)
-    m_game.m_activePlayers.at(i)->setBetDefaults(m_game.m_minBet, m_game.m_maxBet);
-
-  // Make all labels / boxes / cardwidgets for every player
-  playerBox = new PlayerBox *[m_game.m_activePlayers.count()]; // not nice but more easy to use ;-)
-
-  for (int unsigned i = 0; i < m_game.m_activePlayers.count(); i++) {
+  for (int unsigned i = 0; i < numPlayers; i++) {
     playerBox[i] = new PlayerBox(i == 0, this);
-    playerBox[i]->setPlayer(m_game.m_activePlayers.at(i));
+    playerBox[i]->setPlayer(&m_players[i]);
     if (i == 0)
       topLayout->insertWidget(0, playerBox[i]);
     else
       topLayout->addWidget(playerBox[i]);
     playerBox[i]->showName();
-    playerBox[i]->hide();
-    playerBox[i]->show();	// if it has been deleted and created again it
-				// hasn't be shown correctly - hiding and
-				// re-showing solves the problem
 
+    // If it has been deleted and created again it hasn't be shown
+    // correctly - hiding and re-showing solves the problem.
+    playerBox[i]->hide();
+    playerBox[i]->show();
   }
 
   // Connects for player 1
-  playerBox[0]->activateToggleHeld(); // make CardWidget::toggleHeld() work
+  //
+  // FIXME: Make CardWidget::toggleHeld() work.
+  playerBox[0]->activateToggleHeld(); 
   connect(playerBox[0], SIGNAL(toggleHeld()), this, SLOT(toggleHeld()));
 
   // hide some things
   playerBox[0]->showHelds(false);
   wonLabel->hide();
   emit showClickToHold(false);
-  if (m_game.m_activePlayers.count() > 1) {
+
+  // Different meaning of the status for single and multi player games.
+  if (m_game.getNumActivePlayers() > 1) {
     setHand(i18n("Nobody"), false);
     betBox->show();
     betBox->setEnabled(false);
@@ -621,15 +665,15 @@ void kpok::initPoker(int numPlayers, PokerPlayer* ownAllPlayers)
     playerBox[0]->singlePlayerGame(cashPerRound);
   }
 
-  // some final inits
+  // Some final inits.
   drawStat = 0;
   waveActive = 0;
   fCount = 0;
 
-  // finally clear the pot and show the decks/cash - in one word: begin :-)
+  // Finally clear the pot and show the decks/cash - in one word: begin :-)
   m_game.clearPot();
   drawAllDecks();
-  for (int unsigned i = 0; i < m_game.m_activePlayers.count(); i++) {
+  for (unsigned int i = 0; i < m_numPlayers; i++) {
     playerBox[i]->repaintCard();
   }
   paintCash();
@@ -639,7 +683,7 @@ void kpok::initPoker(int numPlayers, PokerPlayer* ownAllPlayers)
 
 void kpok::paintCash()
 {
-  for (int unsigned i = 0; i < m_game.m_activePlayers.count(); i++) {
+  for (unsigned int i = 0; i < m_numPlayers; i++) {
     playerBox[i]->showCash();
   }
   potLabel->setText(i18n("Pot: %1").arg(KGlobal::locale()->formatMoney(m_game.getPot())));
@@ -648,9 +692,9 @@ void kpok::paintCash()
 
 void kpok::updateLHLabel()
 {
-  if (lastHandText != "")
+  if (!lastHandText.isEmpty())
     setHand(lastHandText);
-  else if (getPlayers() > 1)
+  else if (m_game.getNumActivePlayers() > 1)
     setHand(i18n("Nobody"), false);
   else
     setHand(i18n("Nothing"));
@@ -667,7 +711,7 @@ void kpok::setHand(const QString& newHand, bool lastHand)
 
 void kpok::toggleHeld()
 {
-  if (m_game.getState() == StateBet || m_game.getState() == StateContinueBet)
+  if (m_game.getState() == StateBet1 || m_game.getState() == StateRaise1)
     playSound("hold.wav");
 }
 
@@ -677,22 +721,21 @@ void kpok::drawClick()
   if (!drawButton->isEnabled())
     return;
 
-  // If this is the start of a new round, then get new cards.
+  // If this is the start of a new round, then deal new cards.
   if (m_game.getState() == StateStartRound) {
     drawButton->setEnabled(false);
     betBox->setEnabled(false);
     newRound();
   }
-  else if (m_game.getState() == StateBet) { // bet
+  else if (m_game.getState() == StateBet1) { // bet
     emit showClickToHold(false);
-    //clickToHold->hide();
 
     bet();
     if (m_game.getState() == StateExchangeCards) {// should be set in bet()
       drawClick();
     }
   }
-  else if (m_game.getState() == StateContinueBet) { // continue bet
+  else if (m_game.getState() == StateRaise1) { // continue bet
     bet();
     if (m_game.getState() == StateExchangeCards) {// should be set in bet()
       drawClick();
@@ -706,9 +749,9 @@ void kpok::drawClick()
     for (int i = 0; i < PokerHandSize; i++)
       skip[i] = false;
 
-    for (int unsigned i = 0; i < m_game.m_activePlayers.count(); i++) {
-      if (!m_game.m_activePlayers.at(i)->getHuman())
-	m_game.m_activePlayers.at(i)->exchangeCards(skip);
+    for (int i = 0; i < m_game.getNumActivePlayers(); i++) {
+      if (!m_game.getActivePlayer(i)->getHuman())
+	m_game.getActivePlayer(i)->exchangeCards(skip);
       else {
 	for (int i = 0; i < PokerHandSize; i++) {
 	  skip[i] = playerBox[0]->getHeld(i);
@@ -716,7 +759,7 @@ void kpok::drawClick()
 	    playerBox[0]->paintDeck(i);
 	}
       }
-      drawCards(m_game.m_activePlayers.at(i), skip);
+      drawCards(m_game.getActivePlayer(i), skip);
     }
 
     if (playerBox[0]->getHeld(0))
@@ -724,14 +767,14 @@ void kpok::drawClick()
     else
       drawTimer->start(drawDelay, TRUE);
   }
-  else if (m_game.getState() == StateRaise) { // raise
+  else if (m_game.getState() == StateBet2) { // raise
     setBetButtonEnabled(false);
     bet();
 
     if (m_game.getState() == StateSee)//should be set in bet()->if no one has raised
       drawClick();
   }
-  else if (m_game.getState() == StateContinueRaise) {
+  else if (m_game.getState() == StateRaise2) {
     bet();
     if (m_game.getState() == StateSee)
       drawClick();
@@ -750,9 +793,9 @@ void kpok::drawCards(PokerPlayer* p, bool skip[])
 void kpok::displayWinner_Computer(PokerPlayer* winner, bool othersPassed)
 {
   // Determine the box that contains the winner.
-  for (int unsigned i = 0; i < m_game.m_activePlayers.count() + m_game.m_removedPlayers.count(); i++) {
-    if (&m_game.m_players[i] == winner)
-      blinkingBox = i;
+  for (unsigned int i = 0; i < m_numPlayers; i++) {
+    if (&m_players[i] == winner)
+      m_blinkingBox = i;
   }
 
   // Give the pot to the winner.
@@ -792,18 +835,18 @@ void kpok::displayWinner_Computer(PokerPlayer* winner, bool othersPassed)
   paintCash();
 
   // Only start blinking if player 1 is still in.
-  if (m_game.m_activePlayers.contains(&m_game.m_players[0]) && !othersPassed)
+  if (m_game.isActivePlayer(&m_players[0]) && !othersPassed)
     startBlinking();
 
-  drawButton->setText(i18n("&Draw"));
+  drawButton->setText(i18n("&Deal New Round"));
 }
 
 
 void kpok::showComputerCards()
 {
   // Don't show cards of 'out' players.
-  for (int unsigned i = 0; i < m_game.m_activePlayers.count(); i++) {
-    if (!m_game.m_activePlayers.at(i)->getHuman()){
+  for (int i = 0; i < m_game.getNumActivePlayers(); i++) {
+    if (!m_game.getActivePlayer(i)->getHuman()){
       playerBox[i]->paintCard(drawStat); //TODO change: 
 
       if (i == 1) //TODO : CHANGE!
@@ -841,12 +884,12 @@ void kpok::drawCardsEvent()
     drawStat = 0;
 
     if (m_game.getState() == StateExchangeCards) {
-      if (m_game.m_activePlayers.count() == 1)
+      if (m_game.getType() == SinglePlayer)
 	result();
       else {
 	// Now give players the chance to raise.
 	drawButton->setText(i18n("&See!"));
-	m_game.setState(StateRaise);
+	m_game.setState(StateBet2);
       }
     } else if (m_game.getState() == StateStartRound) {
       playerBox[0]->setHeldEnabled(true);
@@ -854,8 +897,8 @@ void kpok::drawCardsEvent()
       emit showClickToHold(true);
       //clickToHold->show();
       //TODO:
-      m_game.setState(StateBet);
-      //drawButton->setText(i18n("&Draw new cards"));
+      m_game.setState(StateBet1);
+      drawButton->setText(i18n("&Draw New Cards"));
     }
 
   } else { // only inc drawStat if not done with displaying
@@ -873,10 +916,10 @@ void kpok::drawCardsEvent()
 
 void kpok::result()
 {
-  int testResult = m_game.m_activePlayers.at(0)->testHand();
+  int testResult = m_game.getActivePlayer(0)->testHand();
   switch (testResult) {
   case Pair:
-    if (m_game.m_activePlayers.at(0)->getHand().get_firstRank() < JACK) {
+    if (m_game.getActivePlayer(0)->getHand().get_firstRank() < JACK) {
       displayWin(i18n("Nothing"), 0); 
       break;
     }
@@ -924,7 +967,7 @@ void kpok::result()
   startBlinking();
   m_game.setState(StateStartRound);
 
-  if (m_game.m_activePlayers.at(0)->getCash() < cashPerRound)
+  if (m_game.getActivePlayer(0)->getCash() < cashPerRound)
     noMoney();
 }
 
@@ -937,11 +980,11 @@ void kpok::winner()
 
   showComputerCards();
 
-  winner = m_game.m_activePlayers.at(0);
-  for (unsigned int i = 1; i < m_game.m_activePlayers.count(); i++) {
-    if (winner->getHand() < m_game.m_activePlayers.at(i)->getHand()) {
+  winner = m_game.getActivePlayer(0);
+  for (int i = 1; i < m_game.getNumActivePlayers(); i++) {
+    if (winner->getHand() < m_game.getActivePlayer(i)->getHand()) {
       //kdDebug() << "Hand 2 is better." << endl;
-      winner = m_game.m_activePlayers.at(i);
+      winner = m_game.getActivePlayer(i);
     }
     else {
       //kdDebug() << "Hand 1 is better." << endl;
@@ -969,8 +1012,8 @@ void kpok::startBlinking()
 void kpok::stopBlinking()
 {
   blinkTimer->stop();
-  blinkStat   = 1;
-  blinkingBox = 0;
+  m_blinkStat   = 1;
+  m_blinkingBox = 0;
 }
 
 
@@ -1005,13 +1048,13 @@ void kpok::waveTimerEvent()
 
 void kpok::bTimerEvent()
 {
-  if (blinking) {
-    if (blinkStat != 0) {
-      playerBox[blinkingBox]->blinkOn();
-      blinkStat=0;
+  if (m_blinking) {
+    if (m_blinkStat != 0) {
+      playerBox[m_blinkingBox]->blinkOn();
+      m_blinkStat = 0;
     } else {
-      playerBox[blinkingBox]->blinkOff();
-      blinkStat=1;
+      playerBox[m_blinkingBox]->blinkOff();
+      m_blinkStat = 1;
     }
   }
 }
@@ -1022,7 +1065,8 @@ void kpok::displayWin(const QString& hand, int cashWon)
   QString buf;
 
   setHand(hand);
-  m_game.m_activePlayers.at(0)->setCash(m_game.m_activePlayers.at(0)->getCash() + cashWon);
+  m_game.getActivePlayer(0)->setCash(m_game.getActivePlayer(0)->getCash()
+				     + cashWon);
   m_game.setDirty();
   paintCash();
 
@@ -1042,7 +1086,7 @@ void kpok::displayWin(const QString& hand, int cashWon)
     startWave();
   }
 
-  //drawButton->setText(i18n("&Deal new round"));
+  drawButton->setText(i18n("&Deal New Round"));
 }
 
 
@@ -1118,9 +1162,9 @@ void kpok::paintEvent( QPaintEvent *)
 
 void kpok::drawAllDecks()
 {
-  for (int unsigned i = 0; i < m_game.m_activePlayers.count(); i++) {
+  for (int i = 0; i < m_game.getNumActivePlayers(); i++) {
     for (int i2 = 0; i2 < PokerHandSize; i2++) {
-      m_game.m_activePlayers.at(i)->takeCard(i2, 0);
+      m_game.getActivePlayer(i)->takeCard(i2, 0);
       playerBox[i]->paintCard(i2);
     }
   }
@@ -1130,12 +1174,9 @@ void kpok::drawAllDecks()
 void kpok::removePlayerFromRound(PokerPlayer* removePlayer)
 {
   removePlayer->setOut(true);
+  m_game.inactivatePlayer(removePlayer);
 
-  m_game.m_removedPlayers.append(removePlayer);
-  if (m_game.m_activePlayers.contains(removePlayer))
-    m_game.m_activePlayers.remove(removePlayer);
-
-  for (int unsigned i = 0; i < m_game.m_activePlayers.count() + m_game.m_removedPlayers.count(); i++)
+  for (int i = 0; i < m_game.getNumPlayers(); i++)
     playerBox[i]->showCash();
 }
 
@@ -1147,11 +1188,12 @@ void kpok::switchToOnePlayerRules()
 			   i18n("You Won"));
 
   // Hide all computer players.
-  for (int unsigned i = 1; i < m_game.m_activePlayers.count() + m_game.m_removedPlayers.count(); i++) {
+  for (unsigned int i = 1; i < m_numPlayers; i++) {
     playerBox[i]->hide();
   }
 
-  m_game.m_removedPlayers.clear();
+  m_game.setType(SinglePlayer);
+
   betBox->hide();
   potLabel->hide();
   playerBox[0]->singlePlayerGame(cashPerRound);
@@ -1161,26 +1203,25 @@ void kpok::switchToOnePlayerRules()
 
 PokerPlayer* kpok::findHumanPlayer()
 {
-  for (int unsigned i = 0; i < m_game.m_activePlayers.count(); i++) {
-    if (m_game.m_activePlayers.at(i)->getHuman())
-      return m_game.m_activePlayers.at(i);
+  for (int i = 0; i < m_game.getNumActivePlayers(); i++) {
+    if (m_game.getActivePlayer(i)->getHuman())
+      return m_game.getActivePlayer(i);
   }
 
-  return m_game.m_activePlayers.at(0);//error
+  return m_game.getActivePlayer(0);//error
 }
 
 
 bool kpok::readEntriesAndInitPoker()
 {
-  NewGameDlg* newGameDlg = NULL;
-  KConfig* conf = kapp->config();
-  int players = DEFAULT_PLAYERS;
-  PokerPlayer* newPlayers = 0;
+  NewGameDlg  *newGameDlg = NULL;
+  KConfig     *conf       = kapp->config();
+  int          numPlayers = DEFAULT_PLAYERS;
 
   conf->setGroup("NewGameDlg");
   bool showNewGameDlg = conf->readBoolEntry("showNewGameDlgOnStartup", false);
-  bool aborted = false;
-  bool oldGame = false;
+  bool aborted        = false;
+  bool oldGame        = false;
 
   if (showNewGameDlg) {
     newGameDlg = new NewGameDlg(this);
@@ -1190,7 +1231,8 @@ bool kpok::readEntriesAndInitPoker()
 
   if (!aborted && (!showNewGameDlg || showNewGameDlg &&
 		   newGameDlg->readFromConfigFile())) {
-    //try starting an old game
+    // Try starting an old game.
+    //kdDebug() << "Trying to load old game" << endl;
     oldGame = loadGame();
     if (oldGame)
       return true;
@@ -1199,25 +1241,17 @@ bool kpok::readEntriesAndInitPoker()
   if (!aborted && showNewGameDlg && !oldGame) {
     // Don't use config file - just take the values from the dialog.
     // (This is also config - the dialog defaults are from config.)
-    players = newGameDlg->getPlayers();
-    if (players <= 0)
+    numPlayers = newGameDlg->getPlayers();
+    if (numPlayers <= 0)
       aborted = true;
-    else {
-      newPlayers = new PokerPlayer[players];
-      newPlayers[0].setHuman();
-    }
 
-    for (int i = 0; i < players; i++) {
-      newPlayers[i].setName(newGameDlg->name(i));
-      newPlayers[i].setCash(newGameDlg->money());
+    for (int i = 0; i < numPlayers; i++) {
+      m_players[i].setName(newGameDlg->name(i));
+      m_players[i].setCash(newGameDlg->money());
       m_game.setDirty();
     }
   }
-
-  if (aborted || !showNewGameDlg && !oldGame) // user didn't say what he/she wants -> use standards
-    initPoker(players);
-  else // whatever user said: we have already a 'newPlayers'
-    initPoker(players, newPlayers);
+  initPoker(numPlayers);
 
   if (newGameDlg != 0) {
     delete newGameDlg;
@@ -1232,19 +1266,19 @@ void kpok::betChange(int betChange)
   PokerPlayer* p = findHumanPlayer();
 
   switch(m_game.getState()){
-  case StateBet:
-    if (p->getCurrentBet() + betChange >= m_game.m_minBet &&
-	p->getCurrentBet() + betChange <= m_game.m_maxBet) {
-      // Bet at least m_minBet but not more than m_maxBet.
+  case StateBet1:
+    if (p->getCurrentBet() + betChange >= m_game.getMinBet() &&
+	p->getCurrentBet() + betChange <= m_game.getMaxBet()) {
+      // Bet at least getMinBet() but not more than getMaxBet().
       if (p->changeBet(betChange))
 	m_game.bet(betChange);
     }
     break;
-  case StateRaise:
-  case StateContinueRaise:
-  case StateContinueBet:
+  case StateBet2:
+  case StateRaise2:
+  case StateRaise1:
     if (p->getCurrentBet() + betChange >= currentMustBet
-	&& p->getCurrentBet() + betChange <= currentMustBet + m_game.m_maxBet) {
+	&& p->getCurrentBet() + betChange <= currentMustBet + m_game.getMaxBet()) {
       if (p->changeBet(betChange))
 	m_game.bet(betChange);
     }
@@ -1267,15 +1301,15 @@ void kpok::saveGame()
 void kpok::saveGame(KConfig* conf)
 {
   // kdWarning() << "save game" << endl;
-  int players = m_game.m_numPlayers;
+  int players = m_game.getNumPlayers();
 
   conf->writeEntry("players", players);
   conf->writeEntry("lastHandText", lastHandText);
 
   for (int i = 0; i < players; i++) {
-    conf->writeEntry(QString("Name_%1").arg(i),  m_game.m_players[i].getName());
-    conf->writeEntry(QString("Human_%1").arg(i), m_game.m_players[i].getHuman());
-    conf->writeEntry(QString("Cash_%1").arg(i),  m_game.m_players[i].getCash());
+    conf->writeEntry(QString("Name_%1").arg(i),  m_players[i].getName());
+    conf->writeEntry(QString("Human_%1").arg(i), m_players[i].getHuman());
+    conf->writeEntry(QString("Cash_%1").arg(i),  m_players[i].getCash());
   }
   
   m_game.clearDirty();
@@ -1283,18 +1317,20 @@ void kpok::saveGame(KConfig* conf)
 
 
 void kpok::toggleSound()    { setSound(!sound); }
-void kpok::toggleBlinking() { setBlinking(!blinking); }
+void kpok::toggleBlinking() { setBlinking(!m_blinking); }
 void kpok::toggleAdjust()   { setAdjust(!adjust); }
 
 
 void kpok::slotPreferences()
 {
   if ( mOptions==0 )
-    mOptions = new OptionsDlg(this, 0, m_game.m_activePlayers.count() + m_game.m_removedPlayers.count());
-  if (m_game.m_activePlayers.count() + m_game.m_removedPlayers.count() > 1)
-    mOptions->init(drawDelay, m_game.m_maxBet, m_game.m_minBet);
+    mOptions = new OptionsDlg(this, 0, m_numPlayers);
+
+  if (m_numPlayers > 1)
+    mOptions->init(drawDelay, m_game.getMaxBet(), m_game.getMinBet());
   else
     mOptions->init(drawDelay, cashPerRound);
+
   if (!mOptions->exec()) {
     delete mOptions;
     mOptions = 0;
@@ -1307,8 +1343,8 @@ void kpok::setAdjust(bool ad)
   adjust = ad;
 
   //update guessed money statusbar if we currently are in need of adjust
-  if (m_game.getState() == StateContinueBet 
-      || m_game.getState() == StateContinueRaise) {
+  if (m_game.getState() == StateRaise1 
+      || m_game.getState() == StateRaise2) {
     if (adjust)
       adjustBet();
     else
@@ -1340,11 +1376,11 @@ void kpok::setSound(bool s)
 void kpok::readOptions()
 {
   if (mOptions != 0) {
-    if (m_game.m_activePlayers.count() + m_game.m_removedPlayers.count() > 1) {
-      m_game.m_minBet = mOptions->getMinBet();
-      m_game.m_maxBet = mOptions->getMaxBet();
-      for (int unsigned i = 0; i < m_game.m_activePlayers.count(); i++)
-	m_game.m_activePlayers.at(i)->setBetDefaults(m_game.m_minBet, m_game.m_maxBet); // inform players how much they may bet
+    if (m_numPlayers > 1) {
+      m_game.setBettingLimits(mOptions->getMinBet(), mOptions->getMaxBet());
+      for (int i = 0; i < m_game.getNumActivePlayers(); i++)
+	m_game.getActivePlayer(i)->setBetDefaults(m_game.getMinBet(), 
+						   m_game.getMaxBet()); // inform players how much they may bet
     }
     drawDelay = mOptions->getDrawDelay();
     //	kdDebug() << cashPerRound << endl;
@@ -1364,39 +1400,35 @@ bool kpok::loadGame()
 
 bool kpok::loadGame(KConfig* conf)
 {
-  int players = DEFAULT_PLAYERS;
-  PokerPlayer* newPlayers = 0;
-
-  bool oldGame = false;
+  int numPlayers = DEFAULT_PLAYERS;
 
   // conf->setGroup("Save");
-  players = conf->readNumEntry("players", -1);
+  numPlayers = conf->readNumEntry("players", -1);
 
-  if (players > 0) {
-    newPlayers = new PokerPlayer[players];
-
-    for (int i = 0; i < players; i++) {
+  if (numPlayers > 0) {
+    for (int i = 0; i < numPlayers; i++) {
       QString buf = conf->readEntry(QString("Name_%1").arg(i),
 				    "Player");
-      newPlayers[i].setName(buf);
+      m_players[i].setName(buf);
       bool human = conf->readBoolEntry(QString("Human_%1").arg(i),
 				       false);
       if (human)
-	newPlayers[i].setHuman(); // i == 0
+	m_players[i].setHuman(); // i == 0
       int cash = conf->readNumEntry(QString("Cash_%1").arg(i),
 				    START_MONEY);
-      newPlayers[i].setCash(cash);
+      m_players[i].setCash(cash);
       m_game.setDirty();
     }
-    oldGame = true;
-    initPoker(players, newPlayers);
-    // after initPoker because initPoker does a default initialization of lastHandText
+    initPoker(numPlayers);
+
+    // after initPoker because initPoker does a default initialization
+    // of lastHandText
     conf->setGroup("Save");
     lastHandText = conf->readEntry("lastHandText", "");
+
     return true;
   }
-  else
-    players = DEFAULT_PLAYERS;
+
   return false;
 }
 
@@ -1430,13 +1462,13 @@ void kpok::slotCardDeck()
       == QDialog::Accepted) {
 
     // Load backside and front images.
-    if (playerBox && blinking && (blinkStat == 0))
+    if (playerBox && m_blinking && (m_blinkStat == 0))
       bTimerEvent();
 
     cardImages->loadDeck(deckPath);
     cardImages->loadCards(cardPath);
 
-    for (int unsigned i = 0; i < m_game.m_activePlayers.count(); i++) {
+    for (int i = 0; i < m_game.getNumActivePlayers(); i++) {
       playerBox[i]->repaintCard();
     }
 
