@@ -50,8 +50,8 @@ PokerWindow::PokerWindow()
   LHLabel = new QLabel(statusBar());
   LHLabel->adjustSize();
 
-  connect(m_kpok, SIGNAL(changeLastHand(QString, bool)), 
-	  this,   SLOT(setHand(QString, bool)));
+  connect(m_kpok, SIGNAL(changeLastHand(const QString &, bool)), 
+	  this,   SLOT(setHand(const QString &, bool)));
   connect(m_kpok, SIGNAL(showClickToHold(bool)), 
 	  this,   SLOT(showClickToHold(bool)));
   connect(m_kpok, SIGNAL(clearStatusBar()), 
@@ -132,13 +132,17 @@ void PokerWindow::readOptions()
 
   if (m_kpok->getSound() != conf->readBoolEntry("Sound", true))
     soundAction->activate();
+
   if (m_kpok->getBlinking() != conf->readBoolEntry("Blinking", true))
     blinkingAction->activate();
+
   if (m_kpok->getAdjust() != conf->readBoolEntry("Adjust", true))
     adjustAction->activate();
+
   if ( showMenubarAction->isChecked() !=
        conf->readBoolEntry("ShowMenubar", true))
     showMenubarAction->activate();
+
   if ( showStatusbarAction->isChecked() !=
        conf->readBoolEntry("ShowStatusbar", true))
     showStatusbarAction->activate();
@@ -187,11 +191,11 @@ bool PokerWindow::queryClose()
 
 /* Show the hand or winner in the status bar at the lower right.
  *
- * FIXME: This doesn't seem to be used as setHand any more.  It is always
- *        used as showWinner() instead, and should be renamed accordingly.
+ * Which is shown depends on wether this is a one player game or a two
+ * player game.
  */
 
-void PokerWindow::setHand(QString newHand, bool lastHand)
+void PokerWindow::setHand(const QString &newHand, bool lastHand)
 {
   if (lastHand)
     LHLabel->setText(i18n("Last hand: ") + newHand);
