@@ -57,7 +57,7 @@
 //  public void Reset()
 //     Resets to the initial position.
 
-//  public boolean MakeMove(Move m)
+//  public boolean makeMove(Move &move)
 //     Makes the move m. Returns false if the move is not legal or when called
 //     with a move where the player is Score.NOBODY.
 
@@ -97,122 +97,179 @@
 //     for faster updates of a graphical board).
 
 
+#include <assert.h>
+
 #include "Game.h"
 
+
+
 Game::Game()
 {
-  // JAVA m_positions = new Position[61];
-  // JAVA m_positions[0] = new Position();
-  m_positions[0].constrInit();
-  m_movenumber = 0;
+  newGame();
 }
 
-void Game::Reset()
+
+// Start a new game and reset the position to before the first move.
+//
+
+void Game::newGame()
 {
-  // JAVA m_positions = new Position[61];
-  // JAVA m_positions[0] = new Position();
-  m_positions[0].constrInit();
-  m_movenumber = 0;
+  m_position.constrInit();
+  m_lastPosition.constrInit();
+
+  m_moveNumber = 0;
 }
 
 
-bool Game::MakeMove(Move m)
+// Return the color of the square at (x, y)
+//
+
+Color Game::color(uint x, uint y) const
 {
-  if (m.GetPlayer() == Nobody) return false;
-  if (GetWhoseTurn() != m.GetPlayer()) return false;
-  if (! m_positions[m_movenumber].MoveIsLegal(m)) return false;
-
-  m_positions[m_movenumber+1].constrCopy(m_positions[m_movenumber], m);
-  m_movenumber++;
-
-  return true;
+  return m_position.color(x, y);
 }
 
 
-bool Game::TakeBackMove()
+// Return the score, i.e. the number of pieces, for color at the
+// current position.
+//
+
+uint Game::score(Color color) const
 {
-  if (m_movenumber <= 0) return false;
-
-  // JAVA m_positions[m_movenumber--] = null;
-  m_movenumber--;
-
-  return true;
+  return m_position.score(color);
 }
 
 
-Player Game::GetSquare(int x, int y)
+// Return the last move made in the game.
+//
+
+Move Game::lastMove() const 
 {
-  return m_positions[m_movenumber].GetSquare(x, y);
+  // If no moves where made, return a NULL move.
+  if (m_moveNumber == 0)
+    return Move();
+
+  return m_moves[m_moveNumber - 1];
 }
 
 
-int Game::GetScore(Player player)
+Move
+Game::move(uint moveNo) const
 {
-  return m_positions[m_movenumber].GetScore(player);
+  assert(moveNo < m_moveNumber);
+
+  return m_moves[moveNo];
 }
 
 
-Move Game::GetLastMove() { return m_positions[m_movenumber].GetLastMove(); }
 
+// Return true if the move is legal in the current position.
+//
 
-bool Game::MoveIsLegal(Move m)
+bool Game::moveIsLegal(Move &move) const
 {
-  return m_positions[m_movenumber].MoveIsLegal(m);
+  return m_position.moveIsLegal(move);
 }
 
 
-bool Game::MoveIsPossible(Player player)
+// Return true if the color can make a move in the current position.
+
+bool Game::moveIsPossible(Color color) const
 {
-  return m_positions[m_movenumber].MoveIsPossible(player);
+  return m_position.moveIsPossible(color);
 }
 
 
-bool Game::MoveIsAtAllPossible()
+// Return true if any side can make a move in the current position.
+//
+
+bool Game::moveIsAtAllPossible() const
 {
-  return m_positions[m_movenumber].MoveIsAtAllPossible();
+  return m_position.moveIsAtAllPossible();
 }
 
 
-int Game::GetMoveNumber() { return m_movenumber; }
+// Make a move in the game, resulting in a new position.  
+//
+// If everything went well, return true.  Otherwise return false and
+// do nothing.
 
-
-Player Game::GetWhoseTurn()
+bool Game::makeMove(Move &move)
 {
-  if (m_movenumber <= 0) return Black;
+  Position  lastPos = m_position;
 
-  Player player = GetLastMove().GetPlayer();
-  Player opponent = ::opponent(player);
-
-  if (MoveIsPossible(opponent)) return opponent;
-
-  if (MoveIsPossible(player)) return player;
-
-  return Nobody;
-}
-
-Player Game::GetWhoseTurnOpponent() {
-  return opponent( GetWhoseTurn() );
-}
-
-bool Game::squareModified(int x, int y) {
-  if(GetMoveNumber() == 1)
-    return true;
-  else
-    return (bool)(m_positions[m_movenumber].GetSquare(x, y) != m_positions[m_movenumber-1].GetSquare(x, y));
-}
-
-bool Game::wasTurned(int x, int y) {
-  if(GetMoveNumber() == 0)
+  // Some sanity checks.
+  if (move.color() == Nobody)
     return false;
-  else {
-    Player c1 = m_positions[m_movenumber-1].GetSquare(x, y);
-    Player c2 = m_positions[m_movenumber].GetSquare(x, y);
 
-    if(c1 == Nobody)
-      return false;
-    else if(c1 == c2)
-      return false;
-    else
-      return true;
+  if (toMove() != move.color())
+    return false;
+
+  // Don't allow illegal moves.
+  if (! m_position.moveIsLegal(move))
+    return false;
+
+  // Make the move in the position.
+  m_position.makeMove(move);
+  m_moves[m_moveNumber++] = move;
+
+  m_lastPosition = lastPos;
+  return true;
+}
+
+
+// Take back the last move.  
+//
+// Note: The removed move is not remembered, so a redo is not possible.
+//
+
+bool Game::takeBackMove()
+{
+  if (m_moveNumber == 0) 
+    return false;
+
+  m_position.constrInit();
+  m_moveNumber--;
+  for (uint i = 0; i < m_moveNumber; i++) {
+    m_lastPosition = m_position;
+    m_position.makeMove(m_moves[i]);
   }
+
+  return true;
+}
+
+
+// ----------------------------------------------------------------
+//                    Reversi specific methods
+
+
+// Return true if the square at (x, y) was changed during the last move.
+//
+
+bool Game::squareModified(uint x, uint y) const 
+{
+  // If the move number is zero, we want to redraw all squares.
+  // That's why we return true here.
+  if (m_moveNumber == 0)
+    return true;
+
+  return m_position.color(x, y) != m_lastPosition.color(x, y);
+}
+
+
+// Return true if the piece at square (x, y) was turned during the last move.
+//
+
+bool Game::wasTurned(uint x, uint y) const 
+{
+  // Nothing turned before the first move.
+  if (m_moveNumber == 0)
+    return false;
+
+  Color color = m_position.color(x, y);
+
+  if (color == Nobody)
+    return false;
+
+  return color != m_lastPosition.color(x, y);
 }
