@@ -44,31 +44,35 @@
  *******************************************************************
  */
 
-// The class Score maintains the score for two players. The constants
-// BLACK and WHITE are used to access the scores for each player. The constant
-// NOBODY can be used in any context where a value other than WHITE and BLACK
-// is meaningful. The function GetOpponent() transforms WHITE to BLACK and
-// vice versa. The other funcions are self explanatory.
-
 #ifndef __SCORE__H__
 #define __SCORE__H__
 
-enum Player { Nobody = -1, White = 0, Black = 1 };
-Player opponent(Player player);
+#include <qglobal.h>
+
+enum Color { White = 0, Black = 1, NbColors = 2, Nobody = NbColors };
+
+Color opponent(Color color);
+
+
+/* This class keeps track of the score for both colors.  Such a score
+ * could be either the number of pieces, the score from the evaluation
+ * function or anything similar.
+ */
 
 class Score {
 public:
   Score();
-  Score(int whitescore, int blackscore);
-  void ScoreCopy(Score &s);
-  void InitScore(int w, int b) { SetScore(Black, b); SetScore(White, w); }
-  int GetScore(Player player);
-  void SetScore(Player player, int score);
-  void ScoreAdd(Player player, int amount);
-  void ScoreSubtract(Player player, int amount);
 
+  uint score(Color color) const     { return m_score[color]; }
+
+  void set(Color color, uint score) { m_score[color] = score; }
+  void inc(Color color)             { m_score[color]++; }
+  void dec(Color color)             { m_score[color]--; }
+  void add(Color color, uint s)     { m_score[color] += s; }
+  void sub(Color color, uint s)     { m_score[color] -= s; }
+  
 private:
-  int m_score[2];
+  uint  m_score[NbColors];
 };
 
 #endif
