@@ -16,29 +16,33 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
+
 #ifndef HIGHSCORES_H
 #define HIGHSCORES_H
 
-#include <kexthighscore.h>
 
+#include <kexthighscore.h>
+#include <kdemacros.h>
 #include "SuperEngine.h"
 
+
 namespace KExtHighscore
 {
 
-class ExtManager : public Manager
+class KDE_EXPORT ExtManager : public Manager
 {
  public:
-    ExtManager();
+  ExtManager();
 
  private:
-    QString gameTypeLabel(uint gameTye, LabelType) const;
-    void convertLegacy(uint gameType);
+  QString gameTypeLabel(uint gameTye, LabelType) const;
+  void convertLegacy(uint gameType);
     
-    struct Data {
-      const char *label, *icon;
-    };
-    static const Data DATA[SuperEngine::NbStrengths];
+  struct Data {
+    const char  *label;
+    const char  *icon;
+  };
+  static const Data  DATA[SuperEngine::NbStrengths];
 };
 
 }
