@@ -36,18 +36,24 @@
  *******************************************************************
  */
 
+
 #include <kapplication.h>
 #include <kimageio.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
+#include <khighscore.h>
 
 #include "version.h"
 #include "kreversi.h"
+#include "highscores.h"
 
-static const char *description = I18N_NOOP("KDE Board Game");
+
+static const char description[] = I18N_NOOP("KDE Board Game");
 
 int main(int argc, char **argv)
 {
+  KHighscore::init("kreversi");
+
   KAboutData aboutData( "kreversi", I18N_NOOP("KReversi"),
     KREVERSI_VERSION, description, KAboutData::License_GPL,
     "(c) 1997-2000, Mario Weilguni");
@@ -56,6 +62,7 @@ int main(int argc, char **argv)
   aboutData.addCredit("Mats Luthman", I18N_NOOP("Game engine, ported from his JAVA applet."), 0);
   aboutData.addCredit("Stephan Kulow", I18N_NOOP("Comments and bugfixes."), 0);
   aboutData.addCredit("Arne Klaassen", I18N_NOOP("Raytraced chips."), 0);
+  aboutData.addCredit("Inge Wallin", I18N_NOOP("Cleaning, bugfixes, some enhancements."), 0);
 
   KCmdLineArgs::init( argc, argv, &aboutData );
 
@@ -64,8 +71,9 @@ int main(int argc, char **argv)
 
   // used for loading background pixmaps
   KImageIO::registerFormats();
+  KExtHighscore::ExtManager highscores;
 
-  if(a.isRestored()){
+  if (a.isRestored()){
      RESTORE(KReversi)
   }
   else {
@@ -73,6 +81,7 @@ int main(int argc, char **argv)
     a.setMainWidget(kreversi);
     kreversi->show();
   }
+
   return a.exec();
 }
 
