@@ -77,6 +77,16 @@ StoneField::~StoneField() {
     kdDebug() << "~StoneField\n" << endl;
 }
 
+int StoneField::count(int color){
+  int c = 0;
+  Stone *stone=field;
+  for (int i=0;i<maxstone;i++,stone++) {
+    if(stone->color == color)
+      c++;
+  }
+  return c;
+}
+
 int
 StoneField::width() const {
     return sizex;
@@ -118,7 +128,6 @@ StoneField::reset() {
         undolist->clear();
     }
 
-
     int c[7];
     int j;
     for (j=0;j<7;j++) c[j]=0;
@@ -130,7 +139,6 @@ StoneField::reset() {
     kdDebug() << "blue   " << c[2] << endl;
     kdDebug() << "yellow " << c[3] << endl;
     kdDebug() << "green  " << c[4] << endl;
-
 }
 
 int
