@@ -1,4 +1,10 @@
 /**
+ * Copyright Michel Filippi <mfilippi@sade.rhein-main.de>
+ *           Robert Williams
+ *           Andrew Chant <andrew.chant@utoronto.ca>
+ *           André Luiz dos Santos <andre@netvision.com.br>
+ *           Benjamin Meyer <ben+ksnake@meyerhome.net>
+ *       
  * This file is part of the ksnake package
  *
  * This program is free software; you can redistribute it and/or modify
@@ -56,7 +62,7 @@ Game::Game(QWidget *parent, const char *name) :  KMainWindow(parent,name)
 
 	levels = new Levels();
 
-	view = new View(this, "View"); 
+	view = new View(this, "View");
 	rattler = view->rattler;
 	rattler->reloadRoomPixmap();
 	rattler->setFocus();
@@ -82,11 +88,11 @@ Game::~Game()
 }
 
 void Game::scoreChanged(int score){
-	statusBar()->changeItem(QString(i18n("Score: %1")).arg(score), SCORE);
+	statusBar()->changeItem(i18n("Score: %1").arg(score), SCORE);
 }
 
 void Game::setTrys(int tries){
-	statusBar()->changeItem(QString(i18n("Lives: %1")).arg(tries), LIVES);
+	statusBar()->changeItem(i18n("Lives: %1").arg(tries), LIVES);
 }
 
 void Game::gameEnd(int score){
@@ -120,10 +126,10 @@ void Game::createMenu()
 	KStdGameAction::quit( this, SLOT(close()), actionCollection());
 
 	KStdAction::preferences(this, SLOT(showSettings()), actionCollection());
-	
-	// TODO change and make custom function that pauses game or 
+
+	// TODO change and make custom function that pauses game or
 	// modify widget to pause when loosing focus and remove this
-	KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), 
+	KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()),
 actionCollection());
 }
 
@@ -140,12 +146,12 @@ void Game::togglePaused()
 void Game::showSettings(){
   if(KConfigDialog::showDialog("settings"))
     return;
-  
+
   KConfigDialog *dialog = new KConfigDialog(this, "settings", Settings::self());
   dialog->addPage(new General(0, "General"), i18n("General"), "package_settings");
-  
+
   Appearance *a = new Appearance(0, "Appearance");
-  
+
 
   QStringList list;
 
@@ -161,11 +167,11 @@ void Game::showSettings(){
 	    list.append(s);
 	}
     }
-  
+
 	a->kcfg_bgimage->insertStringList(list);
-  
+
 	dialog->addPage(a, i18n("Appearance"), "style");
-  
+
 	dialog->addPage(new StartRoom(0, "StartRoom"), i18n("First Level"), "folder_home");
 	connect(dialog, SIGNAL(settingsChanged()), rattler, SLOT(loadSettings()));
 	dialog->show();
