@@ -17,6 +17,8 @@
     Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
+
 #include "kexthighscore_gui.h"
 #include "kexthighscore_gui.moc"
 
@@ -491,7 +493,7 @@ bool ConfigDialog::save()
 
     // do not bother the user with "nickname empty" if he has not
     // messed with nickname settings ...
-    QString newName = _nickname->text().lower();
+    QString newName = _nickname->text();
     if ( newName.isEmpty() && !internal->playerInfos().isAnonymous()
          && !enabled ) return true;
 
