@@ -17,6 +17,8 @@
     Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
+
 #include "kexthighscore_internal.h"
 
 #include <pwd.h>
@@ -34,9 +36,9 @@
 #include <kmdcodec.h>
 #include <kdebug.h>
 
-#include "config.h"
 #include "kexthighscore.h"
 #include "kexthighscore_gui.h"
+#include "kemailsettings.h"
 
 
 namespace KExtHighscore
@@ -279,10 +281,10 @@ PlayerInfos::PlayerInfos()
     addItem("max lost trend", new Item((uint)0), true, true);
     addItem("max won trend", new Item((uint)0), true, true);
 
-#ifdef HIGHSCORE_DIRECTORY
     struct passwd *pwd = getpwuid(getuid());
     QString username = pwd->pw_name;
-    internal->hsConfig().setHighscoreGroup("users");
+#ifdef HIGHSCORE_DIRECTORY
+    internal->hsConfig().setHighscoreGroup("players");
     for (uint i=0; ;i++) {
         if ( !internal->hsConfig().hasEntry(i+1, "username") ) {
             _newPlayer = true;
@@ -297,9 +299,14 @@ PlayerInfos::PlayerInfos()
     }
 #endif
     internal->hsConfig().lockForWriting();
+	KEMailSettings emailConfig;
+	emailConfig.setProfile(emailConfig.defaultProfileName());
+	QString name = emailConfig.getSetting(KEMailSettings::RealName);
+	if ( name.isEmpty() || isNameUsed(name) ) name = username;
+	if ( isNameUsed(name) ) name= QString(ItemContainer::ANONYMOUS);
 #ifdef HIGHSCORE_DIRECTORY
     internal->hsConfig().writeEntry(_id+1, "username", username);
-    item("name")->write(_id, QString(ItemContainer::ANONYMOUS));
+    item("name")->write(_id, name);
 #endif
 
     ConfigGroup cg;
@@ -327,7 +334,7 @@ PlayerInfos::PlayerInfos()
     else {
         _id = nbEntries();
         cg.config()->writeEntry(HS_ID, _id);
-        item("name")->write(_id, QString(ItemContainer::ANONYMOUS));
+        item("name")->write(_id, name);
     }
 #endif
     internal->hsConfig().writeAndUnlock();
@@ -452,7 +459,7 @@ bool PlayerInfos::isNameUsed(const QString &newName) const
 {
     if ( newName==name() ) return false; // own name...
     for (uint i=0; i<nbEntries(); i++)
-        if ( newName==item("name")->read(i).toString() ) return true;
+        if ( newName.lower()==item("name")->read(i).toString().lower() ) return true;
     if ( newName==i18n(ItemContainer::ANONYMOUS_LABEL) ) return true;
     return false;
 }
@@ -505,7 +512,7 @@ void PlayerInfos::removeKey()
 //-----------------------------------------------------------------------------
 ManagerPrivate::ManagerPrivate(uint nbGameTypes, Manager &m)
     : manager(m), showStatistics(false), showDrawGames(false),
-      trackLostGames(false), trackDrawGames(false), 
+      trackLostGames(false), trackDrawGames(false),
       showMode(Manager::ShowForHigherScore),
       _first(true), _nbGameTypes(nbGameTypes), _gameType(0)
 {}
