@@ -170,6 +170,7 @@ void KGameDialogNetworkConfig::slotInitConnection()
  if (host.isNull()) {
 	master = true;
 	if (game()) {
+		game()->setDiscoveryInfo(d->mConnect->type(),d->mConnect->gameName());
 		connected = game()->offerConnections(port);
 	}
  } else {
@@ -239,6 +240,12 @@ void KGameDialogNetworkConfig::setDefaultNetworkInfo(const QString& host, unsign
  }
 }
 
+void KGameDialogNetworkConfig::setDiscoveryInfo(const QString& type, const QString& name)
+{
+ d->mConnect->setType(type);
+ d->mConnect->setName(name);
+} 
+
 /////////////////////////// KGameDialogGeneralConfig /////////////////////////
 class KGameDialogGeneralConfigPrivate
 {
