@@ -18,7 +18,7 @@
     Boston, MA 02111-1307, USA.
 */
 /*
-    $Id: kgame.cpp,v 1.89 2003/07/01 00:31:38 mueller Exp $
+    $Id: kgame.cpp 343769 2004-09-03 17:02:49Z annma $
 */
 
 #include "kgame.h"
@@ -1282,8 +1282,13 @@ void KGame::slotServerDisconnected() // Client side
 
   for ( player=removeList.first(); player != 0; player=removeList.next() )
   {
-    kdDebug(11001) << " ---> Removing player " << player->id() <<  endl;
-    systemRemovePlayer(player,true); // no network necessary
+    bool remove = true;
+    emit signalReplacePlayerIO(player, &remove);
+    if (remove)
+    {
+      kdDebug(11001) << " ---> Removing player " << player->id() <<  endl;
+      systemRemovePlayer(player,true); // no network necessary
+    }
   }
 
   setMaster();
@@ -1303,7 +1308,8 @@ void KGame::slotServerDisconnected() // Client side
   for ( player=d->mPlayerList.first(); player != 0; player=d->mPlayerList.next() ) 
   {
     int oldid=player->id();
-    player->setId(KGameMessage::createPlayerId(player->id(),gameId()));
+    d->mUniquePlayerNumber++;
+    player->setId(KGameMessage::createPlayerId(d->mUniquePlayerNumber,gameId()));
     kdDebug(11001) << "Player id " << oldid <<" changed to " << player->id() << " as we are now local" << endl;
   }
   // TODO clear inactive lists ?
