@@ -18,7 +18,7 @@
     Boston, MA 02111-1307, USA.
 */
 /*
-    $Id: kgamemessage.cpp,v 1.11 2002/10/11 15:56:22 andreas Exp $
+    $Id: kgamemessage.cpp 210396 2003-02-28 23:29:45Z andreas $
 */
 
 #include "kgamemessage.h"
@@ -27,32 +27,38 @@
 
 #define MESSAGE_VERSION 2
 
-Q_UINT32 KGameMessage::rawGameId(Q_UINT32 playerid)
-{
-  return (playerid&0xfc00)>>10;
-}
-int KGameMessage::rawPlayerId(Q_UINT32 playerid)
-{
-  return playerid&0x03ff;
-}
-
-bool KGameMessage::isPlayer(int msgid)
-{
-  if (msgid&0xfc00) return true;
-  else return false;
-}
-bool KGameMessage::isGame(int msgid)
-{
-  return !isPlayer(msgid);
-}
 Q_UINT32 KGameMessage::createPlayerId(int oldplayerid,Q_UINT32 gameid)
 {
   int p;
-  p=oldplayerid&0x3ff; // remove game id
-  p|= (gameid <<10);
+  p = oldplayerid & 0x3ff; // remove game id
+  p |= (gameid << 10);
   return p;
 }
 
+int KGameMessage::rawPlayerId(Q_UINT32 playerid)
+{
+  return playerid & 0x03ff;
+}
+
+Q_UINT32 KGameMessage::rawGameId(Q_UINT32 playerid)
+{
+  return (playerid & 0xfc00) >> 10;
+}
+
+bool KGameMessage::isPlayer(Q_UINT32 msgid)
+{
+  if (msgid & 0xfc00) {
+	return true;
+  } else {
+	return false;
+  }
+}
+
+bool KGameMessage::isGame(Q_UINT32 msgid)
+{
+  return !isPlayer(msgid);
+}
+
 
 void KGameMessage::createHeader(QDataStream &msg,Q_UINT32 sender,Q_UINT32 receiver,int msgid)
 {
