@@ -18,37 +18,44 @@
     Boston, MA 02111-1307, USA.
 */
 /*
-    $Id: kgamenetwork.cpp,v 1.38 2002/06/29 09:54:00 heni Exp $
+    $Id: kgamenetwork.cpp 371633 2004-12-18 13:06:25Z qbast $
 */
 
-#include <qbuffer.h>
-
-#include <kdebug.h>
-
 #include "kgamenetwork.h"
+#include "kgamenetwork.moc"
 #include "kgamemessage.h"
 #include "kgameerror.h"
 
 #include "kmessageserver.h"
 #include "kmessageclient.h"
 #include "kmessageio.h"
+#include <dnssd/publicservice.h>
+
+#include <kdebug.h>
+
+#include <qbuffer.h>
+
 
 class KGameNetworkPrivate
 {
 public:
-	KGameNetworkPrivate()
-	{
-		mMessageClient = 0;
-		mMessageServer = 0;
-    mDisconnectId = 0;
-	}
+        KGameNetworkPrivate()
+        {
+                mMessageClient = 0;
+                mMessageServer = 0;
+                mDisconnectId = 0;
+		mService = 0;
+        }
 
 public:
-	KMessageClient* mMessageClient;
-	KMessageServer* mMessageServer;
-  Q_UINT32 mDisconnectId;  // Stores gameId() over a disconnect process
+        KMessageClient* mMessageClient;
+        KMessageServer* mMessageServer;
+        Q_UINT32 mDisconnectId;  // Stores gameId() over a disconnect process
+	DNSSD::PublicService* mService;
+	QString mType;
+	QString mName;
 
-	int mCookie;
+        int mCookie;
 };
 
 // ------------------- NETWORK GAME ------------------------
@@ -61,26 +68,31 @@ KGameNetwork::KGameNetwork(int c, QObject* parent) : QObject(parent, 0)
  // create your own KMessageServer and a KMessageClient connected to it.
  setMaster();
 
- kdDebug(11001) << k_funcinfo << ": this=" << this <<", cookie=" << cookie() << " sizeof(this)="<<sizeof(KGameNetwork) << endl;
+ kdDebug(11001) << k_funcinfo << "this=" << this <<", cookie=" << cookie() << " sizeof(this)="<<sizeof(KGameNetwork) << endl;
 }
 
 KGameNetwork::~KGameNetwork()
 {
- kdDebug(11001) << k_funcinfo << ": this=" << this << endl;
+ kdDebug(11001) << k_funcinfo << "this=" << this << endl;
 // Debug();
+ delete d->mService;
  delete d;
 }
 
 // ----------------------------- status methods
 bool KGameNetwork::isNetwork() const
 { return isOfferingConnections() || d->mMessageClient->isNetwork();}
+
 Q_UINT32 KGameNetwork::gameId() const
 {
   //return d->mMessageClient->id() ;
   // Return stored id in the case of disconnect. In any other
   // case the disconnect id is 0
-  if (d->mMessageClient->id()!=0 ) return d->mMessageClient->id() ;
-  else return d->mDisconnectId;
+  if (d->mMessageClient->id()!=0 ) {
+    return d->mMessageClient->id() ;
+  } else {
+    return d->mDisconnectId;
+  }
 }
 
 int KGameNetwork::cookie() const
@@ -102,40 +114,68 @@ KMessageServer* KGameNetwork::messageServer() const
 void KGameNetwork::setMaster()
 {
  if (!d->mMessageServer) {
-	d->mMessageServer = new KMessageServer (cookie(), this);
+   d->mMessageServer = new KMessageServer (cookie(), this);
  } else {
-	kdWarning(11001) << k_funcinfo << ": Server already running!!" << endl;
+   kdWarning(11001) << k_funcinfo << "Server already running!!" << endl;
  }
  if (!d->mMessageClient) {
-	d->mMessageClient = new KMessageClient (this);
-  connect (d->mMessageClient, SIGNAL(broadcastReceived(const QByteArray&, Q_UINT32)),
+   d->mMessageClient = new KMessageClient (this);
+   connect (d->mMessageClient, SIGNAL(broadcastReceived(const QByteArray&, Q_UINT32)),
             this, SLOT(receiveNetworkTransmission(const QByteArray&, Q_UINT32)));
-  connect (d->mMessageClient, SIGNAL(connectionBroken()),
-            this, SIGNAL(signalConnectionBroken())); 
-  connect (d->mMessageClient, SIGNAL(aboutToDisconnect(Q_UINT32)),
-            this, SLOT(aboutToLooseConnection(Q_UINT32)));
-  connect (d->mMessageClient, SIGNAL(connectionBroken()),
-            this, SLOT(slotResetConnection())); 
-  
-  connect (d->mMessageClient, SIGNAL(adminStatusChanged(bool)),
+   connect (d->mMessageClient, SIGNAL(connectionBroken()),
+            this, SIGNAL(signalConnectionBroken()));
+   connect (d->mMessageClient, SIGNAL(aboutToDisconnect(Q_UINT32)),
+            this, SLOT(aboutToLoseConnection(Q_UINT32)));
+   connect (d->mMessageClient, SIGNAL(connectionBroken()),
+            this, SLOT(slotResetConnection()));
+
+   connect (d->mMessageClient, SIGNAL(adminStatusChanged(bool)),
             this, SLOT(slotAdminStatusChanged(bool)));
-  connect (d->mMessageClient, SIGNAL(eventClientConnected(Q_UINT32)),
+   connect (d->mMessageClient, SIGNAL(eventClientConnected(Q_UINT32)),
             this, SIGNAL(signalClientConnected(Q_UINT32)));
-  connect (d->mMessageClient, SIGNAL(eventClientDisconnected(Q_UINT32, bool)),
+   connect (d->mMessageClient, SIGNAL(eventClientDisconnected(Q_UINT32, bool)),
             this, SIGNAL(signalClientDisconnected(Q_UINT32, bool)));
 
+   // broacast and direct messages are treated equally on receive.
+   connect (d->mMessageClient, SIGNAL(forwardReceived(const QByteArray&, Q_UINT32, const QValueList<Q_UINT32>&)),
+            d->mMessageClient, SIGNAL(broadcastReceived(const QByteArray&, Q_UINT32)));
+
  } else {
-	// should be no problem but still has to be tested
-	kdDebug(11001) << k_funcinfo << ": Client already exists!" << endl;
+   // should be no problem but still has to be tested
+   kdDebug(11001) << k_funcinfo << "Client already exists!" << endl;
  }
  d->mMessageClient->setServer(d->mMessageServer);
 }
 
+void KGameNetwork::setDiscoveryInfo(const QString& type, const QString& name)
+{
+ kdDebug() << k_funcinfo << type << ":" << name << endl;
+ d->mType = type;
+ d->mName = name;
+ tryPublish();
+}
+
+void KGameNetwork::tryPublish()
+{
+ if (d->mType.isNull() || !isOfferingConnections()) return;
+ if (!d->mService) d->mService = new DNSSD::PublicService(d->mName,d->mType,port());
+ else {
+   if (d->mType!=d->mService->type()) d->mService->setType(d->mType);
+   if (d->mName!=d->mService->serviceName()) d->mService->setServiceName(d->mName);
+   }
+ if (!d->mService->isPublished()) d->mService->publishAsync();
+}
+
+void KGameNetwork::tryStopPublishing()
+{
+ if (d->mService) d->mService->stop();
+}
+
 bool KGameNetwork::offerConnections(Q_UINT16 port)
 {
- kdDebug (11001) << k_funcinfo << ": on port " << port << endl;
+ kdDebug (11001) << k_funcinfo << "on port " << port << endl;
  if (!isMaster()) {
-	setMaster();
+   setMaster();
  }
 
  // Make sure this is 0
@@ -143,26 +183,28 @@ bool KGameNetwork::offerConnections(Q_UINT16 port)
 
  // FIXME: This debug message can be removed when the program is working correct.
  if (d->mMessageServer && d->mMessageServer->isOfferingConnections()) {
-   kdDebug (11001) << k_funcinfo << ": Already running as server! Changing the port now!" << endl;
+   kdDebug (11001) << k_funcinfo << "Already running as server! Changing the port now!" << endl;
  }
 
- kdDebug (11001) << k_funcinfo << ": before Server->initNetwork" << endl;
+ tryStopPublishing();
+ kdDebug (11001) << k_funcinfo << "before Server->initNetwork" << endl;
  if (!d->mMessageServer->initNetwork (port)) {
-   kdError (11001) << k_funcinfo << ": Unable to bind to port " << port << "!" << endl;
+   kdError (11001) << k_funcinfo << "Unable to bind to port " << port << "!" << endl;
    // no need to delete - we just cannot listen to the port
 //   delete d->mMessageServer;
 //   d->mMessageServer = 0;
 //   d->mMessageClient->setServer((KMessageServer*)0);
    return false;
  }
- kdDebug (11001) << k_funcinfo << ": after Server->initNetwork" << endl;
+ kdDebug (11001) << k_funcinfo << "after Server->initNetwork" << endl;
+ tryPublish();
  return true;
 }
 
 bool KGameNetwork::connectToServer (const QString& host, Q_UINT16 port)
 {
  if (host.isEmpty()) {
-   kdError(11001) << k_funcinfo << ": No hostname given" << endl;
+   kdError(11001) << k_funcinfo << "No hostname given" << endl;
    return false;
  }
 
@@ -171,7 +213,7 @@ bool KGameNetwork::connectToServer (const QString& host, Q_UINT16 port)
 
 // if (!d->mMessageServer) {
 //   // FIXME: What shall we do here? Probably must stop a running game.
-//   kdWarning (11001) << k_funcinfo << ": We are already connected to another server!" << endl;
+//   kdWarning (11001) << k_funcinfo << "We are already connected to another server!" << endl;
 /// }
 
  if (d->mMessageServer) {
@@ -197,9 +239,27 @@ bool KGameNetwork::connectToServer (const QString& host, Q_UINT16 port)
  return true;
 }
 
+Q_UINT16 KGameNetwork::port() const
+{
+ if (isNetwork()) {
+   if (isOfferingConnections()) {
+     return d->mMessageServer->serverPort();
+   } else {
+     return d->mMessageClient->peerPort();
+   }
+ }
+ return 0;
+}
+
+QString KGameNetwork::hostName() const
+{
+ return d->mMessageClient->peerName();
+}
+
 bool KGameNetwork::stopServerConnection()
 {
  // We still are the Master, we just don't accept further connections!
+ tryStopPublishing();
  if (d->mMessageServer) {
    d->mMessageServer->stopNetwork();
    return true;
@@ -222,7 +282,7 @@ void KGameNetwork::disconnect()
     {
       kdDebug(11001) << "Client id=" << (*it) <<  endl;
       KMessageIO *client=d->mMessageServer->findClient(*it);
-      if (!client) 
+      if (!client)
       {
         continue;
       }
@@ -239,7 +299,7 @@ void KGameNetwork::disconnect()
  }
  else
  {
-   kdDebug(11001) << k_funcinfo << ": before client->disconnect() id="<<gameId()<< endl;
+   kdDebug(11001) << k_funcinfo << "before client->disconnect() id="<<gameId()<< endl;
    //d->mMessageClient->setServer((KMessageIO*)0);
    kdDebug(11001) << "+++++++++++++++++++++++++++++++++++++++++++++++++++++++"<<endl;
    d->mMessageClient->disconnect();
@@ -257,10 +317,10 @@ void KGameNetwork::disconnect()
   kdDebug(11001) << "  server deleteClients" << endl;
  }
  */
- kdDebug(11001) << k_funcinfo << ": DONE" << endl;
+ kdDebug(11001) << k_funcinfo << "DONE" << endl;
 }
 
-void KGameNetwork::aboutToLooseConnection(Q_UINT32 clientID)
+void KGameNetwork::aboutToLoseConnection(Q_UINT32 clientID)
 {
   kdDebug(11001) << "Storing client id of connection "<<clientID<<endl;
   d->mDisconnectId = clientID;
@@ -275,12 +335,12 @@ void KGameNetwork::slotResetConnection()
 void KGameNetwork::electAdmin(Q_UINT32 clientID)
 {
  if (!isAdmin()) {
-	kdWarning(11001) << k_funcinfo << ": only ADMIN is allowed to call this!" << endl;
+	kdWarning(11001) << k_funcinfo << "only ADMIN is allowed to call this!" << endl;
 	return;
  }
  QByteArray buffer;
  QDataStream stream(buffer,IO_WriteOnly);
- stream << KMessageServer::REQ_ADMIN_CHANGE;
+ stream << static_cast<Q_UINT32>( KMessageServer::REQ_ADMIN_CHANGE );
  stream << clientID;
  d->mMessageClient->sendServerMessage(buffer);
 }
@@ -288,12 +348,12 @@ void KGameNetwork::electAdmin(Q_UINT32 clientID)
 void KGameNetwork::setMaxClients(int max)
 {
  if (!isAdmin()) {
-	kdWarning(11001) << k_funcinfo << ": only ADMIN is allowed to call this!" << endl;
+	kdWarning(11001) << k_funcinfo << "only ADMIN is allowed to call this!" << endl;
 	return;
  }
  QByteArray buffer;
  QDataStream stream(buffer,IO_WriteOnly);
- stream << KMessageServer::REQ_MAX_NUM_CLIENTS;
+ stream << static_cast<Q_UINT32>( KMessageServer::REQ_MAX_NUM_CLIENTS );
  stream << (Q_INT32)max;
  d->mMessageClient->sendServerMessage(buffer);
 }
@@ -341,24 +401,37 @@ bool KGameNetwork::sendSystemMessage(const QByteArray& data, int msgid, Q_UINT32
    sender = gameId();
  }
 
+ Q_UINT32 receiverClient = KGameMessage::rawGameId(receiver); // KGame::gameId()
+ int receiverPlayer = KGameMessage::rawPlayerId(receiver); // KPlayer::id()
+
  KGameMessage::createHeader(stream, sender, receiver, msgid);
  stream.writeRawBytes(data.data(), data.size());
- 
+
  /*
  kdDebug(11001) << "transmitGameClientMessage msgid=" << msgid << " recv="
                 << receiver << " sender=" << sender << " Buffersize="
                 << buffer.size() << endl;
   */
- 
+
  if (!d->mMessageClient) {
    // No client created, this should never happen!
    // Having a local game means we have our own
    // KMessageServer and we are the only client.
-   kdWarning (11001) << k_funcinfo << ": We don't have a client! Should never happen!" << endl;
+   kdWarning (11001) << k_funcinfo << "We don't have a client! Should never happen!" << endl;
    return false;
  }
 
- d->mMessageClient->sendBroadcast(buffer);
+ if (receiverClient == 0 || receiverPlayer != 0)
+ {
+   // if receiverClient == 0 this is a broadcast message. if it is != 0 but
+   // receiverPlayer is also != 0 we have to send broadcast anyway, because the
+   // KPlayer object on all clients needs to receive the message.
+   d->mMessageClient->sendBroadcast(buffer);
+ }
+ else
+ {
+   d->mMessageClient->sendForward(buffer, receiverClient);
+ }
  return true;
 }
 
@@ -392,17 +465,17 @@ void KGameNetwork::receiveNetworkTransmission(const QByteArray& receiveBuffer, Q
  Q_UINT32 sender; // the id of the KGame/KPlayer who sent the message
  Q_UINT32 receiver; // the id of the KGame/KPlayer the message is for 
  KGameMessage::extractHeader(stream, sender, receiver, msgid);
-// kdDebug(11001) << k_funcinfo << ": id=" << msgid << " sender=" << sender << " recv=" << receiver << endl;
+// kdDebug(11001) << k_funcinfo << "id=" << msgid << " sender=" << sender << " recv=" << receiver << endl;
 
  // No broadcast : receiver==0
  // No player isPlayer(receiver)
  // Different game gameId()!=receiver
- if (receiver &&  receiver!=gameId() && !KGameMessage::isPlayer(receiver) ) 
+ if (receiver &&  receiver!=gameId() && !KGameMessage::isPlayer(receiver) )
  {
    // receiver=0 is broadcast or player message
-   kdDebug(11001) << k_funcinfo << ": Message not meant for us " 
-            << gameId() << "!=" << receiver << " rawid=" 
-	    << KGameMessage::rawGameId(receiver) << endl;
+   kdDebug(11001) << k_funcinfo << "Message not meant for us "
+            << gameId() << "!=" << receiver << " rawid="
+            << KGameMessage::rawGameId(receiver) << endl;
    return;
  }
  else if (msgid==KGameMessage::IdError)
@@ -410,7 +483,7 @@ void KGameNetwork::receiveNetworkTransmission(const QByteArray& receiveBuffer, Q
    QString text;
    Q_INT32 error;
    stream >> error;
-   kdDebug(11001) << k_funcinfo << ": Got IdError " << error << endl;
+   kdDebug(11001) << k_funcinfo << "Got IdError " << error << endl;
    text = KGameError::errorText(error, stream);
    kdDebug(11001) << "Error text: " << text.latin1() << endl;
    emit signalNetworkErrorMessage((int)error,text);
@@ -438,4 +511,6 @@ void KGameNetwork::Debug()
  kdDebug(11001) << "---------------------------------------------------" << endl;
 }
 
-#include "kgamenetwork.moc"
+/*
+ * vim: et sw=2
+ */
