@@ -18,14 +18,14 @@
     Boston, MA 02111-1307, USA.
 */
 /*
-    $Id: kgamenetwork.h,v 1.29 2003/10/12 13:32:56 bhards Exp $
+    $Id: kgamenetwork.h 377450 2005-01-11 12:51:23Z mlaurent $
 */
 #ifndef __KGAMENETWORK_H_
 #define __KGAMENETWORK_H_
 
 #include <qstring.h>
 #include <qobject.h>
-
+#include <kdemacros.h>
 class KGameIO;
 class KMessageClient;
 class KMessageServer;
@@ -41,9 +41,9 @@ class KGameNetworkPrivate;
  *
  * @short The main KDE game object
  * @author Martin Heni <martin@heni-online.de>
- * @version $Id: kgamenetwork.h,v 1.29 2003/10/12 13:32:56 bhards Exp $
+ * @version $Id: kgamenetwork.h 377450 2005-01-11 12:51:23Z mlaurent $
  */
-class KGameNetwork : public QObject
+class KDE_EXPORT KGameNetwork : public QObject
 {
   Q_OBJECT
 
@@ -110,6 +110,8 @@ public:
      **/
     bool offerConnections (Q_UINT16 port);
 
+    void setDiscoveryInfo(const QString& type, const QString& name=QString::null);
+    
     /**
      * Inits a network game as a network CLIENT
      *
@@ -411,6 +413,8 @@ protected slots:
 
 
 private:
+     void tryPublish();
+     void tryStopPublishing();
      KGameNetworkPrivate* d;
 };
 
