@@ -18,7 +18,7 @@
     Boston, MA 02111-1307, USA.
 */
 /*
-    $Id: kgamepropertyhandler.cpp,v 1.30 2002/05/27 18:32:30 coolo Exp $
+    $Id: kgamepropertyhandler.cpp 209223 2003-02-25 01:03:19Z antlarr $
 */
 
 #include "kgamepropertyhandler.h"
@@ -378,7 +378,7 @@ QString KGamePropertyHandler::propertyValue(KGamePropertyBase* prop)
 	emit signalRequestValue(prop, value);
  }
 		   
- if (value == QString::null) {
+ if (value.isNull()) {
 	value = i18n("Unknown");
  }
  return value;
