@@ -20,7 +20,8 @@ void MainWindow::init()
 {
     Interface *inter = static_cast<Interface *>(_inter);
     inter->normalGame();
-
+    setFocusPolicy(StrongFocus);
+    
     // Modes
     bool ama = ( bfactory->bbi.nbArcadeStages!=0 );
     QString s = (ama ? i18n("&Single Human (Normal)") : i18n("&Single Human"));
@@ -51,3 +52,9 @@ void MainWindow::saveKeys()
 {
     static_cast<Interface *>(_inter)->saveKeys();
 }
+
+void MainWindow::focusInEvent(QFocusEvent *e)
+{
+    static_cast<Interface *>(_inter)->setFocus();
+    BaseMainWindow::focusInEvent(e);
+}
